agbSubheadings = {
    "1.1.1": "Creation of the heavens and the earth",
    "1.1.3": "Day 1 - Light and darkness",
    "1.1.6": "Day 2 - Firmament and sky",
    "1.1.9": "Day 3 - Dry land, seas, and vegetation",
    "1.1.14": "Day 4 - Sun, moon, and stars",
    "1.1.20": "Day 5 - Sea creatures and birds",
    "1.1.24": "Day 6 - Land animals and humans",
    "1.2.1": "Day 7 - The Sabbath, God's rest",
    "1.2.4": "Creation of Adam and the garden",
    "1.2.10": "The rivers of Eden",
    "1.2.15": "Adam's role and responsibility in the garden",
    "1.2.18": "Creation of Eve from Adam's rib",
    "1.3.1": "The Serpent's deceit",
    "1.3.6": "Adam and Eve's disobedience",
    "1.3.8": "God confronts Adam and Eve",
    "1.3.14": "Punishment of the serpent",
    "1.3.16": "Punishment of Eve",
    "1.3.17": "Punishment of Adam",
    "1.3.20": "The provision of garments for Adam and Eve",
    "1.3.22": "Expulsion from the Garden of Eden",
    "1.4.1": "Birth of Cain and Abel",
    "1.4.3": "The sacrifices of Cain and Abel",
    "1.4.6": "Cain's anger and God's warning",
    "1.4.8": "The murder of Abel",
    "1.4.9": "God's judgment on Cain",
    "1.4.13": "Cain's lament and God's protection",
    "1.4.17": "Birth of Enoch, the first city",
    "1.4.19": "The line of Lamech: the first polygamist",
    "1.4.25": "Birth of Seth",
    "1.5.1": "Genealogy from Adam to Noah",
    "1.6.1": "Sons of God and daughters of men",
    "1.6.5": "The judgment of God",
    "1.6.8": "Noah finds favor with God",
    "1.6.11": "The instructions to build the ark",
    "1.7.1": "Entering the ark",
    "1.7.11": "The onset of the flood",
    "1.7.17": "The destruction of life on earth",
    "1.8.1": "The floodwaters recede",
    "1.8.6": "The raven and the dove",
    "1.8.13": "Exiting the ark",
    "1.8.20": "Noah's sacrifice",
    "1.9.1": "God's covenant with Noah and all living creatures",
    "1.9.18": "The sons of Noah",
    "1.9.20": "Noah and the vineyard",
    "1.9.22": "The curse of Ham and blessing of Shem and Japheth",
    "1.9.28": "The death of Noah",
    "1.10.1": "The genealogy of Noah's sons",
    "1.11.1": "The people build the Tower of Babel",
    "1.11.5": "God confuses the languages",
    "1.11.10": "Genealogy from Shem to Abram",
    "1.12.1": "God's command to Abram and the promise of blessings",
    "1.12.4": "Abram's journey from Haran to Canaan",
    "1.12.7": "God's reaffirmation of the promise and Abram builds an altar",
    "1.12.10": "Abram's decision to go to Egypt and his deception",
    "1.12.14": "Pharaoh's discoveries and confrontations with Abram",
    "1.13.1": "Conflict between Abram and Lot's herdsmen",
    "1.13.8": "Abram and Lot separate, Lot chooses the plain of Jordan",
    "1.13.14": "God's reaffirmation of the promise to Abram",
    "1.14.1": "The War of the Kings and Lot's capture",
    "1.14.13": "Abram's rescue of Lot and his possessions",
    "1.14.17": "Abram's encounter with Melchizedek and the King of Sodom",
    "1.15.1": "God's promise of descendants and Abram's faith",
    "1.15.7": "The covenant ceremony and prophecy of future events",
    "1.16.1": "Sarai, Hagar, and Abram's failure",
    "1.16.7": "The Angel of the Lord encounters Hagar and prophesies about Ishmael",
    "1.17.1": "God reaffirms the covenant with Abram and changes his name to Abraham",
    "1.17.9": "The command of circumcision",
    "1.17.15": "The promise of Isaac and the covenant with Ishmael",
    "1.17.22": "Abraham and his household are circumcised",
    "1.18.1": "The three visitors and the promise of Isaac's birth",
    "1.18.16": "Abraham intercedes for Sodom",
    "1.19.1": "Lot and his family's escape from Sodom's destruction",
    "1.19.30": "Lot's daughters and the birth of Moab and Ammon",
    "1.20.1": "Abraham's deception to Abimelech concerning Sarah",
    "1.20.8": "Abimelech confronts Abraham and returns Sarah",
    "1.21.1": "The birth of Isaac and the Lord's faithfulness",
    "1.21.8": "Hagar and Ishmael's departure",
    "1.22.1": "The binding of Isaac and God's provision of a sacrifice",
    "1.23.1": "Abraham mourns for Sarah and seeks a burial site",
    "1.23.7": "The purchase of the cave of Machpelah for Sarah's burial",
    "1.24.1": "Abraham sends his servant to find a wife for Isaac",
    "1.24.10": "The servant's encounter with Rebekah",
    "1.24.28": "Rebekah's family agrees to the marriage",
    "1.24.62": "Isaac and Rebekah's meeting and marriage",
    "1.25.1": "Abraham's other children and his inheritance",
    "1.25.7": "The death and burial of Abraham",
    "1.25.12": "The Descendants of Ishmael",
    "1.25.19": "The prophecy and birth of Esau and Jacob",
    "1.25.27": "Esau sells his birthright to Jacob",
    "1.26.1": "God's promise to Isaac and instructions",
    "1.26.7": "Isaac's deception concerning Rebekah",
    "1.26.12": "Isaac's prosperity, conflict, and peace with the Philistines",
    "1.26.34": "Esau's marriages to Hittite women",
    "1.27.1": "Isaac's request for Esau to prepare a meal",
    "1.27.5": "Rebekah and Jacob's plan to deceive Isaac",
    "1.27.18": "Jacob receives Isaac's blessing",
    "1.27.30": "Esau's realization and receiving of a secondary blessing",
    "1.27.41": "Esau's plan to kill Jacob and Rebekah's warning",
    "1.27.46": "Rebekah's concern for Jacob and Isaac's blessing for his journey",
    "1.28.6": "Esau's Marriages to the Daughters of Ishmael",
    "1.28.10": "Jacob's Dream at Bethel and the Renewal of the Covenant",
    "1.29.1": "Jacob meets Rachel and Laban",
    "1.29.15": "Jacob agrees to work for Laban and marry his daughters",
    "1.29.31": "The birth of Jacob's sons through Leah",
    "1.30.1": "The birth of Jacob's other sons and daughter",
    "1.30.25": "Jacob's attempts to increase his wealth through his flocks",
    "1.31.1": "God's instruction and Jacob's escape",
    "1.31.22": "Laban's pursuit and confrontation with Jacob",
    "1.31.43": "Laban and Jacob's covenant and separation",
    "1.32.1": "Jacob's prayer and preparations for meeting Esau",
    "1.32.22": "Jacob wrestles with God and receives a new name",
    "1.33.1": "Jacob and Esau's reunion and parting",
    "1.33.18": "Jacob settles in Shechem and builds an altar",
    "1.35.1": "Jacob's journey to Bethel and God's reaffirmation of the covenant",
    "1.35.16": "The death of Rachel and Isaac",
    "1.42.1": "Joseph's brothers' first journey to buy grain in Egypt",
    "1.43.1": "The second journey to Egypt and Joseph's feast with his brothers",
    "1.44.1": "The setup for the accusation and Judah's plea",
    "1.45.1": "Joseph reveals his identity to his brothers",
    "1.46.1": "Jacob's journey to Egypt and reunion with Joseph",
    "1.46.28": "Jacob's audience with Pharaoh and the Israelites' settlement in Goshen",
    "1.47.13": "Joseph's administration during the famine",
    "1.47.27": "Jacob Blesses Joseph's Sons and Adopts Them",
    "1.50.1": "The death of Jacob and his burial in Canaan",
    "1.50.15": "Joseph comforts and reaffirms his forgiveness to his brothers",
    "1.50.22": "The death of Joseph and the promise of return to Canaan",
    "2.1.1": "The Growth of Israel's population",
    "2.1.8": "The Pharaoh's fear and persecution",
    "2.1.15": "The Hebrew midwives' disobedience",
    "2.1.22": "Pharaoh's command to kill male infants",
    "2.2.1": "The birth and rescue of Moses",
    "2.2.11": "Moses kills an Egyptian and flees",
    "2.2.16": "Moses in Midian and his marriage",
    "2.2.23": "God hears Israel's groaning",
    "2.3.1": "The burning bush encounter",
    "2.3.7": "God's promise to deliver Israel",
    "2.3.11": "Moses' initial objections",
    "2.4.1": "Moses' second set of objections and God's reassurances",
    "2.4.18": "Moses' return to Egypt",
    "2.4.21": "The Lord's message to Pharaoh",
    "2.4.24": "Zipporah saves Moses",
    "2.4.27": "Meeting with Aaron and Elders of Israel",
    "2.5.1": "Moses and Aaron's demand to Pharaoh",
    "2.5.6": "Increased work and suffering for the Israelites",
    "2.5.22": "Moses' complaint to God",
    "2.6.1": "God's reassurance and covenant",
    "2.6.14": "Genealogy of Moses and Aaron",
    "2.6.28": "God's renewed command to Moses",
    "2.7.1": "The Ten Plagues",
    "2.7.14": "First Plague: Water turned to blood",
    "2.8.1": "Second Plague: Frogs",
    "2.8.16": "Third Plague: Gnats",
    "2.8.20": "Fourth Plague: Flies",
    "2.9.1": "Fifth Plague: Livestock disease",
    "2.9.8": "Sixth Plague: Boils",
    "2.9.13": "Seventh Plague: Hail and fire",
    "2.10.1": "Eighth Plague: Locusts",
    "2.10.21": "Ninth Plague: Darkness",
    "2.11.1": "Tenth Plague: Death of the firstborn",
    "2.12.1": "The institution of the Passover",
    "2.12.31": "The exodus from Egypt",
    "2.13.1": "Consecration of firstborn and reminder of Passover",
    "2.13.17": "Pillar of cloud and fire",
    "2.14.1": "Crossing the Red Sea",
    "2.15.1": "The Song of Moses and Miriam",
    "2.15.22": "Bitter water turned sweet at Marah",
    "2.16.1": "Manna and quail provided by God",
    "2.17.1": "Water from the rock at Massah and Meribah",
    "2.17.8": "Battle against the Amalekites",
    "2.18.1": "Jethro's advice to Moses",
    "2.19.1": "Arrival at Sinai and God's promise",
    "2.19.10": "Preparations for God's appearance",
    "2.20.1": "The Ten Commandments given",
    "2.20.18": "Fear of God and proper worship",
    "2.21.1": "Various laws given",
    "2.24.1": "The Covenant established",
    "2.25.1": "Offerings for the tabernacle",
    "2.25.10": "Ark of the covenant",
    "2.25.23": "Table for showbread",
    "2.25.31": "Golden lampstand",
    "2.26.1": "Tabernacle architecture",
    "2.27.1": "Bronze altar and courtyard",
    "2.27.20": "Oil for the lamp",
    "2.28.1": "Priestly garments",
    "2.29.1": "Consecration of priests",
    "2.30.1": "Altar of incense",
    "2.30.11": "Census tax, basin, and anointing oil",
    "2.31.1": "Appointment of craftsmen",
    "2.31.12": "Sabbath rules",
    "2.32.1": "The idolatry of the golden calf",
    "2.32.7": "God's anger and Moses' intercession",
    "2.32.15": "Destruction of the golden calf",
    "2.33.1": "God's command to leave Sinai",
    "2.33.7": "Moses' request for God's presence",
    "2.34.1": "The new set of the Ten Commandments",
    "2.35.1": "The Sabbath law reiterated",
    "2.35.4": "The construction of the tabernacle begins",
    "2.37.1": "Completing the tabernacle and its furnishings",
    "2.39.1": "Crafting of priestly garments",
    "2.39.32": "Presentation of tabernacle to Moses",
    "2.40.1": "Assembly and blessing of the tabernacle",
    "2.40.34": "The glory of the Lord filling the tabernacle",
    "3.1.1": "Offerings from the herd",
    "3.1.10": "Offerings from the flock",
    "3.1.14": "Offerings from birds",
    "3.2.1": "Offerings of fine flour",
    "3.2.4": "Baked grain offerings",
    "3.2.11": "Firstfruits offerings",
    "3.3.1": "Offerings from the herd",
    "3.3.6": "Offerings from the flock",
    "3.4.1": "Offerings for the high priest",
    "3.4.13": "Offerings for the congregation",
    "3.4.22": "Offerings for leaders",
    "3.4.27": "Offerings for individuals",
    "3.5.1": "Offerings for unintentional sins",
    "3.5.14": "Offerings for misuse of holy things",
    "3.6.1": "Offerings for dishonesty",
    "3.6.8": "Burnt offerings",
    "3.6.14": "Grain offerings",
    "3.6.24": "Sin offerings",
    "3.7.1": "Guilt offerings",
    "3.7.11": "Peace offerings",
    "3.7.37": "Summary of regulations",
    "3.8.1": "Consecration of Aaron and his sons",
    "3.9.1": "Beginning of the priestly service",
    "3.10.1": "The death of Nadab and Abihu",
    "3.10.8": "Instructions on priestly conduct",
    "3.11.1": "Clean and unclean animals",
    "3.12.1": "Purification after childbirth",
    "3.13.1": "Laws on skin diseases and mildew",
    "3.14.1": "Cleansing from skin diseases and mildew",
    "3.15.1": "Discharges causing uncleanness",
    "3.16.1": "Instructions for the Day of Atonement",
    "3.16.29": "The perpetual statute",
    "3.17.1": "Blood and its sanctity",
    "3.18.1": "Sexual relations and holiness",
    "3.19.1": "Moral and ceremonial holiness",
    "3.20.1": "Punishments for disobedience",
    "3.21.1": "Holiness in the priesthood",
    "3.22.1": "Acceptable and unacceptable offerings",
    "3.23.1": "Annual feasts and holy days",
    "3.24.1": "The use of oil and bread in the sanctuary",
    "3.24.10": "Blasphemy and its punishment",
    "3.25.1": "Sabbatical and Jubilee years",
    "3.26.1": "Blessings for obedience and curses for disobedience",
    "3.27.1": "Valuation of dedicated persons",
    "3.27.9": "Valuation of dedicated animals",
    "3.27.14": "Valuation of dedicated houses and land",
    "3.27.26": "Rules on vows and consecrations",
    "3.27.30": "Tithes",
    "3.27.34": "Conclusion",
    "4.1.1": "The Lord's Command",
    "4.1.5": "Assembly of the leaders",
    "4.1.17": "The Census",
    "4.1.47": "Excluding the Levites",
    "4.2.1": "East Side Tribes",
    "4.2.11": "South Side Tribes",
    "4.2.17": "Levites in the Center",
    "4.2.18": "West Side Tribes",
    "4.2.25": "North Side Tribes",
    "4.2.32": "Total Count",
    "4.3.1": "Aaron's Priesthood",
    "4.3.5": "Duties of the Levite Clans",
    "4.4.1": "The Kohathite Service",
    "4.4.21": "The Gershonite and Merarite Services",
    "4.5.1": "Removal of the Unclean",
    "4.5.5": "Restitution for Wrongs",
    "4.5.11": "The Test of Adultery",
    "4.6.1": "Nazirite Vow",
    "4.6.22": "Priestly Blessing",
    "4.7.1": "Offerings of the Leaders",
    "4.7.89": "Summarizing the Offerings",
    "4.8.1": "Setting up the Lamps",
    "4.8.5": "Levite Consecration",
    "4.9.1": "Second Passover",
    "4.10.1": "Silver Trumpets",
    "4.10.11": "Departure from Sinai",
    "4.11.1": "The Lord's Response to Complaints",
    "4.11.4": "The People's Craving for Meat",
    "4.12.1": "Miriam and Aaron's Opposition to Moses",
    "4.13.1": "Spies Sent to Canaan",
    "4.14.1": "Rebellion of the People",
    "4.15.1": "Laws and Offerings",
    "4.16.1": "Rebellion of Korah",
    "4.17.1": "Aaron's Rod",
    "4.18.1": "Duties of the Priests and Levites",
    "4.19.1": "Red Heifer",
    "4.20.1": "Death of Miriam and Water from the Rock",
    "4.20.14": "Edom Refuses Passage",
    "4.20.22": "Death of Aaron",
    "4.21.1": "Defeat of the Canaanite King of Arad",
    "4.21.4": "The Bronze Serpent",
    "4.22.1": "Balak's Request",
    "4.22.15": "Balaam's Journey",
    "4.23.1": "Balaam's First and Second Oracles",
    "4.24.1": "Balaam's Third and Fourth Oracles",
    "4.25.1": "Baal Worship and Punishment",
    "4.26.1": "Census of the New Generation",
    "4.27.1": "Land Inheritance Laws",
    "4.27.12": "Joshua Appointed Leader",
    "4.28.1": "Various Offerings",
    "4.31.1": "Vengeance on the Midianites",
    "4.32.1": "Transjordan Tribes: Reuben, Gad, and Half of Manasseh",
    "4.33.1": "Summary of Israel's Journey",
    "4.33.50": "Instructions for Conquering Canaan",
    "4.34.1": "Boundaries of the Promised Land",
    "4.34.16": "Leaders to Divide the Land",
    "4.35.1": "Cities for the Levites and Cities of Refuge",
    "4.36.1": "Inheritance Laws for Daughters",
    "5.1.1": "The Setting",
    "5.1.6": "Departure from Horeb",
    "5.1.9": "Appointment of Leaders",
    "5.1.19": "Spies and Rebellion",
    "5.2.1": "Edomite, Moabite, and Ammonite Lands",
    "5.2.24": "Conquest of Sihon",
    "5.3.1": "Conquest of Og",
    "5.3.12": "Distribution of the Conquered Lands",
    "5.3.23": "Moses Forbidden to Enter the Promised Land",
    "5.4.1": "Obedience and Prosperity",
    "5.4.9": "Warning against Idolatry",
    "5.4.32": "The Lord is God",
    "5.4.41": "Cities of Refuge",
    "5.4.44": "Provisions of the Covenant",
    "5.5.1": "The Ten Commandments",
    "5.5.22": "The Essence of the Covenant Relationship",
    "5.6.1": "The Great Commandment",
    "5.6.10": "Warning against Forgetfulness and Idolatry",
    "5.7.1": "Rules Regarding Conquest and Separation",
    "5.8.1": "Blessings for Obedience",
    "5.8.11": "Warnings against Disobedience",
    "5.9.1": "Israel's Rebellion Reviewed",
    "5.10.1": "The Second Pair of Tablets",
    "5.10.12": "Summary of the Commandments",
    "5.12.1": "Laws concerning Worship and Idolatry",
    "5.14.3": "Dietary Laws",
    "5.14.22": "Tithes and Offerings",
    "5.15.1": "Sabbath Year and Debt Release",
    "5.15.19": "Firstborn Animals",
    "5.16.1": "The Passover, Feast of Weeks, and Feast of Tabernacles",
    "5.16.18": "Laws concerning Judges and Justice",
    "5.16.21": "Forbidden Religious Practices",
    "5.19.1": "Cities of Refuge and Landmark Laws",
    "5.20.1": "Laws on Warfare",
    "5.21.1": "Miscellaneous Laws",
    "5.23.1": "Marriage, Family, and Social Regulations",
    "5.26.1": "Offerings and Tithes",
    "5.27.1": "Altar on Mount Ebal",
    "5.27.9": "Curses for Disobedience",
    "5.28.1": "Blessings for Obedience",
    "5.28.15": "Curses for Disobedience",
    "5.29.1": "The Covenant Renewal",
    "5.30.1": "God's Future Blessing and Judgment",
    "5.31.1": "The Charge to Joshua",
    "5.31.9": "The Reading and Safeguarding of the Law",
    "5.31.14": "Israel's Disobedience Predicted",
    "5.32.1": "The Song of Moses",
    "5.33.1": "Moses Blesses the Tribes of Israel",
    "5.34.1": "The Death of Moses and Succession of Joshua",
    "6.1.1": "Command to cross the Jordan",
    "6.1.5": "Divine promise of victory",
    "6.1.10": "Instructing the Israelites",
    "6.1.16": "Oath of allegiance",
    "6.2.1": "Entering the city",
    "6.2.8": "Rahab's assistance",
    "6.2.22": "Return and report",
    "6.3.1": "Levitical ark role",
    "6.3.14": "Miraculous crossing",
    "6.4.1": "Memorial stones",
    "6.5.1": "Circumcision command",
    "6.5.10": "Passover celebration",
    "6.5.13": "Divine warrior's appearance",
    "6.6.1": "Jericho battle plan",
    "6.7.1": "Israel's defeat at Ai",
    "6.7.6": "Achan's sin revealed",
    "6.8.1": "Ai's successful capture",
    "6.8.30": "Altar building",
    "6.8.33": "Covenant ratification",
    "6.9.1": "Deceptive ploy",
    "6.9.16": "Treaty discovery",
    "6.9.22": "Subservient role for Gibeonites",
    "6.10.1": "Southern campaign begins",
    "6.10.6": "Gibeonite rescue",
    "6.10.16": "Five kings' capture and execution",
    "6.10.28": "Conquered southern cities",
    "6.11.1": "Kings amass forces",
    "6.11.6": "God's command and assurance",
    "6.11.7": "Decisive victory",
    "6.11.16": "Summary of the conquests",
    "6.12.1": "Defeated eastern kings",
    "6.12.7": "Defeated western kings",
    "6.13.1": "Remaining Lands to Conquer",
    "6.13.8": "Transjordan Allocation",
    "6.13.15": "Reuben's territory",
    "6.13.24": "Gad's territory",
    "6.13.29": "Manasseh's half-tribe of territory",
    "6.14.1": "Canaan Land Division",
    "6.14.6": "Caleb's inheritance",
    "6.15.1": "Judah's territory",
    "6.16.1": "Joseph's two tribes' territories",
    "6.18.1": "Land survey command",
    "6.18.11": "Remaining seven tribes allocations",
    "6.20.1": "Six refuge cities",
    "6.21.1": "Levitical towns",
    "6.22.1": "Joshua's commendation",
    "6.22.10": "Altar of witness",
    "6.23.1": "God's faithfulness",
    "6.23.6": "Appeal for faithfulness",
    "6.23.12": "Warning against alliance with pagans",
    "6.24.1": "Joshua's final address",
    "6.24.14": "Urging loyalty to God",
    "6.24.25": "Renewing covenant and witnesses",
    "6.24.29": "Joshua's death and burial",
    "6.24.32": "Joseph's remains reinterred",
    "6.24.33": "Eleazar's death and burial",
    "7.1.1": "Conquest of Jerusalem and Hebron",
    "7.1.11": "Capture of Debir",
    "7.1.16": "Exploits of the house of Joseph",
    "7.1.21": "Tribes' failure to conquer lands",
    "7.2.6": "Death of Joshua",
    "7.2.11": "Israel's unfaithfulness and consequences",
    "7.3.1": "Nations left to test Israel",
    "7.3.7": "Israel's oppression by Moab",
    "7.3.9": "Othniel's deliverance: freedom from Moab",
    "7.3.12": "Israel's oppression by Moab",
    "7.3.15": "Ehud's deliverance: assassination of Eglon",
    "7.3.26": "Israel's victory over Moab",
    "7.3.31": "Shamgar's deliverance: victory over Philistines",
    "7.4.1": "Israel's oppression by the Canaanites",
    "7.4.5": "Deborah's call to Barak",
    "7.4.11": "Sisera's defeat",
    "7.5.1": "Song of Deborah and Barak",
    "7.6.1": "Israel's oppression by Midian",
    "7.6.7": "The call of Gideon",
    "7.6.25": "Gideon's actions against Baal worship",
    "7.7.1": "Gideon's victory over the Midianites",
    "7.8.22": "Gideon's rule and death",
    "7.9.1": "Abimelech becomes king of Shechem",
    "7.9.7": "Parable of the trees",
    "7.9.16": "Rebellion against Abimelech",
    "7.9.50": "Death of Abimelech",
    "7.10.1": "Rule of Tola",
    "7.10.3": "Rule of Jair",
    "7.10.6": "Israel's oppression by Ammon",
    "7.11.1": "Jephthah's rise to leadership",
    "7.11.12": "Jephthah's negotiations with Ammon",
    "7.11.29": "Jephthah's vow and victory",
    "7.12.1": "Jephthah's conflict with Ephraim",
    "7.12.8": "Rule of Ibzan",
    "7.12.11": "Rule of Elon",
    "7.12.13": "Rule of Abdon",
    "7.13.1": "Birth of Samson",
    "7.14.1": "Samson's marriage and riddle",
    "7.15.1": "Samson's vengeance and foxes",
    "7.15.9": "Samson's capture and triumph",
    "7.16.1": "Samson and Delilah",
    "7.16.23": "Samson's final victory and death",
    "7.17.1": "Micah's idolatry and private priesthood",
    "7.17.7": "The Levite becomes Micah's priest",
    "7.18.1": "Danites take the Levite and Micah's idols",
    "7.19.1": "Levite's journey and arrival in Gibeah",
    "7.19.16": "Outrage at Gibeah",
    "7.20.1": "Israel's response and Benjamin's defeat",
    "7.21.1": "Provision for the surviving Benjamites",
    "8.1.1": "Setting in Time of Judges",
    "8.1.2": "Elimelech and His Family",
    "8.1.3": "Famine and Move to Moab",
    "8.1.4": "Death of Elimelech and Sons Mahlon and Chilion",
    "8.1.6": "Naomi's Decision to Return to Bethlehem",
    "8.1.8": "Naomi's Encouragement for Orpah and Ruth to Stay",
    "8.1.14": "Ruth's Devotion and Pledge",
    "8.1.19": "Arrival to Bethlehem",
    "8.2.1": "Ruth Begins Gleaning",
    "8.2.4": "Boaz's Arrival and Inquiry about Ruth",
    "8.2.8": "Boaz's Encouragement and Protection",
    "8.2.14": "Boaz's Generosity during Mealtime",
    "8.2.17": "Ruth's Continued Gleaning",
    "8.2.19": "Naomi's Recognition of Boaz's Kindness",
    "8.2.22": "Ruth's Continued Gleaning for a Season",
    "8.3.1": "Naomi's Counsel to Ruth",
    "8.3.6": "Ruth's Obedience and Proposing to Boaz",
    "8.3.10": "Boaz's Response and Praise",
    "8.3.14": "Boaz's Provision and Ruth's Departure",
    "8.3.16": "Ruth's Report to Naomi",
    "8.4.1": "Boaz Meets the Near Kinsman",
    "8.4.3": "Boaz Presents the Situation",
    "8.4.5": "Near Kinsman's Relinquishment of Rights",
    "8.4.7": "Boaz's Affirmation of Redemption",
    "8.4.11": "Witnesses and Elders Bless Boaz and Ruth",
    "8.4.13": "Boaz and Ruth Marry",
    "8.4.14": "Birth of Obed",
    "8.4.18": "The Genealogy of David",
    "9.1.1": "Introduction of Samuel's Parents",
    "9.1.9": "Hannah's Prayer and Promise",
    "9.1.19": "The Birth of Samuel",
    "9.2.1": "Hannah's Song of Thanksgiving",
    "9.2.11": "Samuel's Dedication in the Temple",
    "9.2.12": "The Wickedness of Eli's Sons",
    "9.2.18": "Comparison of Samuel and Eli's Sons",
    "9.2.27": "Prophecy Against Eli's Household",
    "9.3.1": "The Lord Calls Samuel",
    "9.3.15": "Samuel's Prophecy Fulfilled",
    "9.4.1": "Samuel Established as a Prophet",
    "9.4.2": "Defeat of Israel and Capture of the Ark",
    "9.5.1": "The Ark in Philistine Territory",
    "9.6.1": "Philistines Return the Ark",
    "9.7.1": "The Ark at Kiriath-Jearim",
    "9.7.2": "Israel's Repentance and Revival",
    "9.7.7": "Victory over the Philistines",
    "9.7.15": "Samuel's Circuit of Judgeship",
    "9.8.1": "Israel Demands a King",
    "9.9.1": "Saul's Encounter with Samuel",
    "9.10.1": "Saul Anointed by Samuel",
    "9.10.17": "Saul Publicly Chosen",
    "9.11.1": "Victory over the Ammonites",
    "9.12.1": "Samuel's Farewell Address",
    "9.13.1": "Saul's Disobedience and Rejection",
    "9.14.1": "Jonathan's Victory over Philistines",
    "9.15.1": "Amalekite Campaign and Rejection of Saul",
    "9.16.1": "David Anointed by Samuel",
    "9.16.14": "David Enters Saul's Service",
    "9.17.1": "David's Victory over Goliath",
    "9.18.1": "David's Friendship with Jonathan",
    "9.18.6": "David's Growing Popularity",
    "9.19.1": "Jonathan's Warnings and Escape",
    "9.20.1": "Jonathan's Covenant with David",
    "9.21.1": "David Flees to Nob",
    "9.21.10": "David's Feigned Insanity at Gath",
    "9.22.1": "David at Adullam and Mizpeh",
    "9.22.6": "Saul's Massacre at Nob",
    "9.23.1": "David's Deliverance of Keilah",
    "9.23.14": "David at Ziph and Maon",
    "9.24.1": "Saul's Attempt to Kill David",
    "9.25.1": "Abigail Intervenes with David",
    "9.26.1": "David's Second Mercy to Saul",
    "9.27.1": "David Serves Achish",
    "9.28.1": "David's True Loyalties",
    "9.28.3": "The Consultation of the Witch of Endor",
    "9.29.1": "David's Denied Participation in Battle",
    "9.30.1": "David's Rescue of Ziklag",
    "9.31.1": "The Death of Saul and His Sons",
    "10.1.1": "David is informed of Saul and Jonathan's death by an Amalekite",
    "10.1.11": "David mourns for Saul and Jonathan",
    "10.1.13": "David seeks justice for Saul's death",
    "10.1.17": "David's lament for Saul and Jonathan",
    "10.2.1": "David inquires of the Lord, moves to Hebron",
    "10.2.4": "David anointed as king of Judah",
    "10.2.5": "David's message to Jabesh-Gilead",
    "10.2.8": "Abner makes Ish-bosheth king over Israel",
    "10.2.12": "Battle of Gibeon",
    "10.2.18": "Asahel chases Abner",
    "10.2.24": "Joab halts pursuit of Abner",
    "10.3.1": "David's growing family",
    "10.3.6": "Abner's dispute with Ish-bosheth",
    "10.3.12": "Abner reaches out to David",
    "10.3.22": "Joab's reaction to Abner",
    "10.3.31": "David mourns Abner",
    "10.4.1": "Murder of Ish-bosheth",
    "10.4.9": "David's judgment on Ish-bosheth's murderers",
    "10.5.1": "David anointed as king over Israel",
    "10.5.6": "David captures Jerusalem",
    "10.5.17": "David's military victory over the Philistines",
    "10.6.1": "The Ark's journey towards Jerusalem",
    "10.6.6": "Uzzah's death",
    "10.6.12": "David moves the Ark to Jerusalem",
    "10.6.16": "Michal's disdain for David's celebration",
    "10.7.1": "David's desire to build a temple",
    "10.7.4": "God's response to David",
    "10.7.18": "David's prayer of gratitude",
    "10.8.1": "David defeats the Philistines and Moabites",
    "10.8.3": "David defeats Hadadezer",
    "10.8.9": "David's victory over the Ammonites and Syrian allies",
    "10.8.15": "David's administration",
    "10.9.1": "David's kindness to Mephibosheth",
    "10.10.1": "Battle with the Ammonites and Syrians",
    "10.11.1": "David's sin with Bathsheba",
    "10.11.6": "David's attempt to deceive Uriah",
    "10.11.14": "Uriah's death",
    "10.12.1": "Nathan confronts David",
    "10.12.15": "Death of David's son and birth of Solomon",
    "10.12.26": "David's victory over the Ammonites",
    "10.13.1": "Amnon's sin with Tamar",
    "10.13.23": "Absalom's revenge and exile",
    "10.14.1": "The return of Absalom",
    "10.15.1": "Absalom's conspiracy",
    "10.15.13": "David flees Jerusalem",
    "10.16.1": "David encounters Ziba, Shimei, and Hushai",
    "10.17.1": "Absalom enters Jerusalem",
    "10.18.1": "The defeat and death of Absalom",
    "10.18.19": "David receives news about Absalom",
    "10.19.1": "Joab rebukes David",
    "10.19.9": "The tribes of Israel argue over David",
    "10.19.15": "David's return to Jerusalem",
    "10.20.1": "The rebellion of Sheba",
    "10.20.3": "Amasa's death",
    "10.20.14": "Joab captures Sheba",
    "10.20.23": "David's officials",
    "10.21.1": "The Gibeonites' revenge",
    "10.21.15": "Battles with the Philistine giants",
    "10.22.1": "David's song of praise",
    "10.23.1": "David's last words",
    "10.23.8": "David's mighty warriors",
    "10.24.1": "David's census and its punishment",
    "10.24.18": "David builds an altar",
    "11.1.1": "Adonijah's attempt to become king",
    "11.1.11": "Nathan and Bathsheba's intervention",
    "11.1.32": "Solomon's anointing as king",
    "11.1.41": "Adonijah's submission to Solomon",
    "11.2.1": "David's last instructions to Solomon",
    "11.2.10": "David's death and Solomon's reign",
    "11.2.13": "Solomon's consolidation of power",
    "11.3.1": "Solomon's request for wisdom",
    "11.3.16": "The judgment of Solomon",
    "11.5.1": "Preparations for building the Temple",
    "11.6.1": "Construction of the Temple",
    "11.7.1": "Solomon builds his palace",
    "11.7.13": "Making the temple furniture",
    "11.8.1": "Dedication of the Temple",
    "11.9.1": "God's covenant with Solomon",
    "11.9.10": "Solomon's building projects and trade",
    "11.10.1": "Solomon's wisdom and literary works",
    "11.10.14": "Solomon's wealth and splendor",
    "11.11.1": "Solomon's disobedience and downfall",
    "11.11.14": "Adversaries against Solomon",
    "11.11.26": "Jeroboam's rebellion and the prophecy of the divided kingdom",
    "11.12.1": "Rehoboam's folly and the division of the kingdom",
    "11.12.25": "Jeroboam's idolatry and the northern kingdom's apostasy",
    "11.13.1": "The prophecy of the altar's destruction",
    "11.13.33": "Jeroboam's house condemned",
    "11.14.21": "Rehoboam's reign in Judah",
    "11.15.1": "Abijam's reign and Asa's reforms",
    "11.15.25": "Nadab and Baasha: kings of Israel",
    "11.16.8": "Elah, Zimri, and Omri: kings of Israel",
    "11.16.29": "Ahab's reign and the introduction of Baal worship",
    "11.17.1": "Elijah's confrontation with Ahab and the drought",
    "11.17.8": "The widow of Zarephath",
    "11.18.1": "The contest on Mount Carmel",
    "11.19.1": "Elijah flees to Horeb",
    "11.19.9": "God's commission and reassurance to Elijah",
    "11.20.1": "Ben-hadad's siege of Samaria and Ahab's victory",
    "11.20.35": "Ahab's disobedience and prophecy of doom",
    "11.21.1": "Naboth's vineyard and Ahab's covetousness",
    "11.21.17": "Elijah pronounces judgment on Ahab and Jezebel",
    "11.22.1": "The alliance with Jehoshaphat and the battle against Aram",
    "11.22.51": "Ahaziah's reign in Israel",
    "12.1.1": "Ahaziah's Injuries and Inquiry",
    "12.1.9": "Elijah Confronts the Messengers",
    "12.1.17": "Ahaziah's Death",
    "12.2.1": "Elijah's Final Journey",
    "12.2.7": "The Parting of the Jordan River",
    "12.2.9": "Elijah's Departure and Elisha's Request",
    "12.2.13": "Elisha's Initial Miracles",
    "12.4.1": "Elisha and the Widow's Oil",
    "12.4.8": "Elisha and the Shunammite Woman",
    "12.4.38": "Elisha and the Poisonous Stew",
    "12.4.42": "Elisha and the Feeding of One Hundred Men",
    "12.5.1": "Elisha and the Healing of Naaman",
    "12.5.15": "Elisha and Gehazi's Greed",
    "12.6.1": "Elisha and the Floating Axe Head",
    "12.6.8": "Elisha and the Aramean War",
    "12.6.24": "Elisha and the Siege of Samaria",
    "12.8.1": "Elisha and the Shunammite's Land",
    "12.8.7": "Elisha and Hazael",
    "12.8.16": "Jehoram's Wickedness",
    "12.8.20": "Edom and Libnah Revolt",
    "12.8.23": "Jehoram's Death",
    "12.8.25": "Ahaziah's Alliance with Jehoram of Israel",
    "12.8.29": "Ahaziah's Wicked Reign",
    "12.9.1": "Jehu's Anointing",
    "12.9.11": "Jehu Kills Joram and Ahaziah",
    "12.9.30": "Jehu Destroys Jezebel",
    "12.10.1": "Jehu's Massacre of the House of Ahab",
    "12.10.18": "Jehu Kills the Priests of Baal",
    "12.10.29": "Jehu's Incomplete Obedience",
    "12.10.32": "Jehoahaz's Wicked Reign",
    "12.11.2": "Elisha's Final Prophecy and Death",
    "12.11.18": "Jehoahaz's Military Defeats",
    "12.13.10": "Jehoash's Mixed Reign",
    "12.13.14": "The Arrows of Victory",
    "12.13.20": "Elisha's Death and Israel's Victories",
    "12.14.1": "Amaziah's Mixed Reign",
    "12.14.7": "Amaziah's Victories Over Edom",
    "12.14.8": "Amaziah's Failed Challenge to Jehoash",
    "12.14.15": "Amaziah's Death",
    "12.14.23": "Jeroboam's Wicked Reign and Expansion",
    "12.14.29": "Jeroboam's Death",
    "12.15.1": "Azariah's Prosperous and Offensive Reign",
    "12.15.6": "Azariah's Death",
    "12.15.8": "Zechariah's Reign and Murder",
    "12.15.13": "Shallum's Reign and Murder",
    "12.15.16": "Menahem's Reign",
    "12.15.23": "Pekahiah's Reign and Assassination",
    "12.15.27": "Pekah's Reign",
    "12.15.32": "The Reign of Jotham in Judah",
    "13.1.1": "The descendants of Adam through Seth",
    "13.1.5": "The descendants of Noah",
    "13.1.8": "The descendants of Ham",
    "13.1.17": "The descendants of Japheth",
    "13.1.24": "The descendants of Shem",
    "13.1.28": "The descendants of Isaac",
    "13.1.29": "Descendants of Ishmael",
    "13.1.32": "Descendants of Keturah",
    "13.1.34": "Descendants of Esau",
    "13.2.1": "The twelve sons",
    "13.2.3": "Line of Er and Onan",
    "13.2.9": "Line of Hezron",
    "13.2.25": "Line of Jerahmeel",
    "13.2.42": "Line of Caleb",
    "13.3.1": "Descendants of David",
    "13.4.1": "Descendants of Hur",
    "13.4.5": "Descendants of other families of Judah",
    "13.4.24": "The sons of Simeon",
    "13.4.28": "Their cities and conquests",
    "13.5.1": "The sons of Reuben",
    "13.5.4": "Reuben's lineage and conquests",
    "13.5.11": "The sons of Gad",
    "13.5.18": "Descendants of the Half-Tribe of Manasseh",
    "13.5.23": "Lineage of the half-tribe of Manasseh",
    "13.5.25": "Their conquest and captivity",
    "13.6.1": "High Priestly Line",
    "13.6.16": "Descendants of Gershom, Kohath, and Merari",
    "13.6.31": "The singers and musicians",
    "13.6.49": "Additional genealogies of the Levites",
    "13.7.1": "Descendants of Issachar",
    "13.7.6": "Descendants of Benjamin",
    "13.7.13": "Descendants of Naphtali",
    "13.7.14": "Descendants of Manasseh",
    "13.7.20": "Descendants of Ephraim",
    "13.7.30": "Descendants of Asher",
    "13.8.1": "Descendants of Benjamin Revisited",
    "13.9.1": "Israelite returnees",
    "13.9.4": "Summary of Judah and Benjamin",
    "13.9.10": "List of priests",
    "13.9.14": "List of Levites",
    "13.9.35": "King Saul's Family",
    "13.10.1": "Death of Saul and his sons",
    "13.10.8": "David mourns for Saul",
    "13.11.1": "David becomes king",
    "13.11.4": "David captures Jerusalem",
    "13.11.10": "David's mighty men",
    "13.12.1": "David in Ziklag",
    "13.12.23": "David's official coronation",
    "13.13.1": "Transportation of the Ark",
    "13.15.1": "David's celebration and Michal's contempt",
    "13.16.1": "The Ark's arrival in Jerusalem",
    "13.17.1": "Nathan's prophecies and David's prayer",
    "13.18.1": "Conquests of neighboring nations",
    "13.19.1": "War against the Ammonites",
    "13.20.1": "Battles against the Philistines",
    "13.21.1": "David's census and its consequences",
    "13.22.1": "Preparations for building the temple",
    "13.23.1": "Organization of the Levites",
    "13.24.1": "Organization of the priests",
    "13.25.1": "Temple musicians",
    "13.26.1": "Gatekeepers and treasurers",
    "13.27.1": "Military and governmental leaders",
    "13.28.1": "David's final address",
    "13.29.26": "David's death",
    "14.1.1": "Solomon Offers Sacrifices at Gibeon",
    "14.1.7": "Solomon's Prayer for Wisdom",
    "14.1.13": "Solomon's Prosperity",
    "14.2.1": "Solomon Prepares for Construction",
    "14.3.1": "The Temple's Design and Dimensions",
    "14.4.1": "The Construction of the Temple",
    "14.5.2": "The Furnishings in the Temple",
    "14.6.1": "The Dedication of the Temple",
    "14.7.1": "God's Manifestation in the Temple",
    "14.7.11": "God's Promise and Warning to Solomon",
    "14.8.1": "Solomon's Building Projects",
    "14.9.1": "Queen of Sheba's Visit",
    "14.9.13": "Solomon's Wealth and Splendor",
    "14.9.29": "Solomon's Death",
    "14.10.1": "Israel's Division",
    "14.11.1": "Idolatry in Judah",
    "14.12.1": "Rehoboam's Reign",
    "14.13.1": "Abijah",
    "14.14.1": "Asa",
    "14.17.1": "Jehoshaphat",
    "14.21.1": "Jehoram",
    "14.22.1": "Ahaziah",
    "14.22.10": "Athaliah",
    "14.23.16": "Joash",
    "14.25.1": "Amaziah",
    "14.26.1": "Uzziah",
    "14.27.1": "Jotham",
    "14.28.1": "Ahaz",
    "14.29.1": "Hezekiah's Reforms",
    "14.32.1": "Assyrian Invasion",
    "14.32.24": "Hezekiah's Illness and Recovery",
    "14.32.27": "Hezekiah's Pride and Death",
    "14.33.1": "Manasseh's Reign and Restoration",
    "14.33.21": "Amon's Reign and Assassination",
    "14.34.1": "Josiah's Reforms",
    "14.34.14": "The Rediscovery of the Law",
    "14.35.1": "Passover Celebration",
    "14.35.20": "Josiah's Death",
    "14.36.1": "Jehoahaz's Reign",
    "14.36.5": "Jehoiakim's Reign",
    "14.36.9": "Jehoiachin's Reign",
    "14.36.11": "Zedekiah's Reign",
    "14.36.18": "Babylonian Destruction of Jerusalem",
    "14.36.20": "Exile to Babylon",
    "14.36.22": "Proclamation of Cyrus",
    "15.1.1": "Cyrus' proclamation",
    "15.1.5": "Response of the people",
    "15.1.7": "Restoration of temple vessels",
    "15.2.1": "Overview of returning exiles",
    "15.2.3": "List of families and their leaders",
    "15.2.21": "List of towns and their inhabitants",
    "15.2.59": "List of those unable to prove their lineage",
    "15.2.64": "Total count and offerings given",
    "15.3.1": "Establishment of the altar",
    "15.3.4": "Celebration of the Feast of Tabernacles",
    "15.3.7": "Preparations for reconstructing the temple",
    "15.3.10": "Laying the foundation",
    "15.4.1": "Initial opposition",
    "15.4.4": "Attempts to discourage and halt the construction",
    "15.4.24": "Suspension of the work",
    "15.5.1": "Prophetic influence of Haggai and Zechariah",
    "15.5.3": "Interrogation by regional authorities",
    "15.5.6": "Letter to Darius",
    "15.6.1": "Discovery of Cyrus' decree",
    "15.6.6": "Darius' response and provisions",
    "15.6.13": "Restarting and completing construction",
    "15.6.16": "Dedication of the temple",
    "15.6.19": "Celebrating Passover and the Feast of Unleavened Bread",
    "15.7.1": "Ezra's commission",
    "15.7.11": "Letter of Artaxerxes",
    "15.7.27": "Ezra's praise to the Lord",
    "15.8.1": "List of family heads in the second group",
    "15.8.15": "Gathering and fasting by the river",
    "15.8.24": "Dispatch with temple valuables",
    "15.8.31": "Arrival in Jerusalem",
    "15.9.1": "Discovery of forbidden marriages",
    "15.9.5": "Ezra's prayer and confession",
    "15.10.1": "Reform plan and Shecaniah's proposal",
    "15.10.5": "Summoning of the people",
    "15.10.9": "Ezra's address and the people's response",
    "15.10.18": "List of those guilty of intermarriage",
    "16.1.1": "The report from Jerusalem",
    "16.1.4": "Nehemiah's mourning",
    "16.1.5": "Nehemiah's prayer",
    "16.2.1": "The king notices Nehemiah's sadness",
    "16.2.4": "Nehemiah's prayer and request",
    "16.2.9": "Nehemiah arrives in Jerusalem",
    "16.2.12": "Inspection of the walls",
    "16.2.17": "Encouraging the people",
    "16.2.19": "Opposition from Sanballat and Tobiah",
    "16.3.1": "The Sheep Gate",
    "16.3.2": "Various sections of the wall",
    "16.4.1": "Mockery from enemies",
    "16.4.4": "Nehemiah's prayer",
    "16.4.6": "The wall's progress",
    "16.4.7": "Conspiracy of attacks",
    "16.4.9": "Precautions taken",
    "16.5.1": "Complaints about financial oppression",
    "16.5.6": "Nehemiah's solution",
    "16.5.14": "Nehemiah leads by example",
    "16.6.1": "Attempts to lure Nehemiah",
    "16.6.5": "False accusations",
    "16.6.10": "Attempts to intimidate Nehemiah",
    "16.6.15": "The wall's completion",
    "16.6.17": "Continued opposition",
    "16.7.1": "Gates assigned and guarded",
    "16.7.4": "The city's population",
    "16.7.6": "The genealogical record",
    "16.8.1": "Reading of the Law",
    "16.8.9": "Explanation and application",
    "16.8.13": "Rediscovering the Feast of Tabernacles",
    "16.9.1": "Fasting, confession, and worship",
    "16.9.4": "Prayer and recollection of Israel's history",
    "16.9.38": "Renewal of the covenant",
    "16.11.1": "Casting lots for Jerusalem",
    "16.11.3": "List of residents in the city",
    "16.11.25": "Other towns and settlements",
    "16.12.1": "Lists of priests and Levites",
    "16.12.27": "Dedication of the wall",
    "16.12.44": "Organization of the Temple services",
    "16.13.1": "Social reforms",
    "16.13.4": "Repurification of the Temple chambers",
    "16.13.10": "Support for the Levites",
    "16.13.15": "Sabbath reforms",
    "16.13.23": "Correcting mixed marriages",
    "16.13.30": "Nehemiah's final reforms and prayer",
    "17.1.1": "The Feast of King Ahasuerus",
    "17.1.10": "Queen Vashti's Refusal",
    "17.1.13": "Vashti's Deposition",
    "17.2.1": "The Search for a New Queen",
    "17.2.5": "Esther's Background and Introduction",
    "17.2.12": "Esther's Preparation and Favor",
    "17.2.15": "Esther Chosen as Queen",
    "17.2.19": "Mordecai Uncovers a Conspiracy",
    "17.3.1": "Haman's Promotion and Mordecai's Refusal",
    "17.3.7": "Haman's Request for the King's Edict",
    "17.3.12": "The Edict against the Jews",
    "17.4.1": "Mordecai's Mourning",
    "17.4.4": "Esther Informed of the Edict",
    "17.4.10": "Esther's Decision to Act",
    "17.5.1": "Esther's Preparation and Audience with the King",
    "17.5.5": "The First Banquet",
    "17.5.9": "Haman's Boasting and Anger",
    "17.6.1": "The King Honors Mordecai",
    "17.6.12": "Haman's Humiliation",
    "17.7.1": "The Second Banquet",
    "17.7.7": "Haman's Downfall and Execution",
    "17.8.1": "Esther's Request for Jewish Deliverance",
    "17.8.7": "The King's Response and a New Edict",
    "17.8.15": "The Jews Rejoice and Prepare",
    "17.9.1": "The Day of Vengeance",
    "17.9.17": "The Establishment of Purim",
    "17.10.1": "Mordecai's Promotion",
    "18.1.1": "Job's Character and Prosperity",
    "18.1.6": "Satan Challenges Job's Integrity",
    "18.1.13": "Job Loses His Wealth and Children",
    "18.2.1": "Satan Challenges Job's Health",
    "18.2.9": "Job's Wife and Job's Response",
    "18.2.11": "Job's Friends Arrive",
    "18.3.1": "Job Curses the Day of His Birth",
    "18.3.11": "Job Questions Why He Was Born",
    "18.4.1": "Eliphaz Rebukes Job",
    "18.5.1": "Eliphaz Explains Suffering",
    "18.6.1": "Job Defends His Integrity",
    "18.7.1": "Job's Complaint to God",
    "18.8.1": "Bildad Encourages Job",
    "18.8.11": "Bildad Asserts God's Justice",
    "18.9.1": "Job Expresses Inability to Argue with God",
    "18.10.1": "Job Pours Out His Soul to God",
    "18.11.1": "Zophar Accuses Job",
    "18.11.7": "Zophar Declares God's Wisdom",
    "18.12.1": "Job Mocks His Friends",
    "18.13.1": "Job Appeals to God's Wisdom",
    "18.14.1": "Job's Lament of Life's Transience",
    "18.15.1": "Eliphaz Accuses Job of Arrogance",
    "18.15.17": "Eliphaz Portrays the Fate of the Wicked",
    "18.16.1": "Job's Rejection of his Friends' Arguments",
    "18.17.1": "Job Wishes For a Mediator",
    "18.18.1": "Bildad Scorns Job",
    "18.18.5": "Bildad Describes the Wicked's Fate",
    "18.19.1": "Job Describes His Suffering",
    "18.19.23": "Job Expresses Confidence in His Redeemer",
    "18.20.1": "Zophar's Bitter Rebuke",
    "18.20.12": "Zophar Describes the Wicked's Downfall",
    "18.21.1": "The Wicked sometimes Prosper",
    "18.21.17": "The Wicked's Punishment",
    "18.22.1": "Eliphaz Accuses Job of Sin",
    "18.22.21": "Eliphaz Advices Repentance",
    "18.23.1": "Job Desires to Plead His Case",
    "18.24.1": "Job Highlights the Wicked's Prosperity",
    "18.25.1": "God's Majesty and Human Worthlessness",
    "18.26.1": "Job Describes God's Power",
    "18.27.1": "Job Maintains His Integrity",
    "18.28.1": "The Search for Wisdom",
    "18.28.13": "Wisdom's Inaccessibility",
    "18.28.23": "Wisdom Belongs to God",
    "18.29.1": "Job's Former Glory",
    "18.30.1": "Job's Present Misery",
    "18.31.1": "Job's Final Protest of Innocence",
    "18.32.1": "Elihu's Introduction",
    "18.33.1": "Elihu Corrects Job",
    "18.34.1": "Elihu Condemns Job's Three Friends",
    "18.35.1": "Elihu Affirms God's Justice",
    "18.36.1": "Elihu Exalts God's Greatness",
    "18.38.1": "God's Control of the Natural World",
    "18.38.39": "God's Creation of the Animal Kingdom",
    "18.40.1": "Job's Response",
    "18.40.6": "Lessons from Behemoth and Leviathan",
    "18.41.1": "God's Mastery Over Leviathan",
    "18.42.1": "Job's Repentance",
    "18.42.7": "God Condemns Job's Friends",
    "18.42.10": "Job's Restoration",
    "19.1.1": "Introduction to the Two Ways of Life",
    "19.1.2": "The Character and Conduct of the Righteous",
    "19.1.4": "The Character and Consequences of the Wicked",
    "19.1.6": "The Divine Verdict",
    "19.2.1": "Introduction: The Nations Rebelling against God",
    "19.2.4": "God's Response to the Rebellion",
    "19.2.7": "The Proclamation of God's Decree",
    "19.2.10": "The Appeal to the Rulers and Nations",
    "19.3.1": "Introduction: David's Faith in Times of Trouble",
    "19.3.3": "David's Confidence in God's Protection",
    "19.3.5": "David's Peaceful Sleep and Awakening",
    "19.3.7": "David's Prayer for Deliverance",
    "19.4.1": "Introduction: Call for the Lord's Answer",
    "19.4.2": "Warning and Admonishment to the Troublemakers",
    "19.4.3": "Assurance of God's Favor to the Righteous",
    "19.4.4": "Encouragement for the Faithful",
    "19.4.6": "The Contrast between the Faithless and the Faithful",
    "19.4.8": "Trust in the Lord's Protection and Peace",
    "19.5.1": "Introduction: A Cry for Help",
    "19.5.4": "God's Disapproval of Evil",
    "19.5.7": "Seeking Refuge in God",
    "19.5.9": "Accusation of the Wicked",
    "19.5.11": "God's Protection to the Righteous",
    "19.6.1": "Repentant plea for God's mercy",
    "19.6.4": "Prayer for salvation rooted in faith",
    "19.6.6": "Expressions of anguish and sorrow",
    "19.6.8": "Proclamation of victory and assurance",
    "19.7.1": "Introduction: David's Appeal for Justice",
    "19.7.3": "David's Righteousness and Innocence",
    "19.7.6": "God as the Righteous Judge",
    "19.7.11": "God's Punishment for the Wicked",
    "19.7.14": "The Consequences of Wickedness",
    "19.7.17": "David's Praise and Gratitude",
    "19.8.1": "Praising the Majesty of God's Name",
    "19.8.3": "Appreciation for God's Creation",
    "19.8.5": "The Honor and Responsibility of Humans",
    "19.8.9": "Conclusion: Glorifying the Lord's Name",
    "19.9.1": "Praise for God's Justice",
    "19.9.3": "Wicked Nations' Downfall",
    "19.9.7": "God's Eternal Throneship",
    "19.9.9": "The Lord as Refuge",
    "19.9.11": "Proclaiming God's Wondrous Works",
    "19.9.13": "The Prayers of the Humble",
    "19.9.15": "The Fate of the Wicked",
    "19.9.17": "Hope for the Needy",
    "19.9.18": "Remembering the Forgotten",
    "19.10.1": "Introduction: Cry for Justice",
    "19.10.3": "The Character of the Wicked",
    "19.10.12": "David's Appeal to God",
    "19.10.16": "Conclusion: Praise and Confidence in God",
    "19.11.1": "Confident Faith in the Lord",
    "19.11.4": "God's Sovereign Presence and Actions",
    "19.11.7": "Assurance of God's Love and Righteousness",
    "19.12.1": "Introduction: A Plea for Help",
    "19.12.2": "Wickedness in Society",
    "19.12.5": "God's Promise to Act",
    "19.12.6": "The Pure Words of the Lord",
    "19.12.7": "Trust in God's Protection",
    "19.12.8": "The Persistence of Wickedness",
    "19.13.1": "Introduction: Cry for Help",
    "19.13.3": "Supplication: David's Plea for Deliverance",
    "19.13.5": "Affirmation: Trust in God's Steadfast Love",
    "19.14.1": "Introduction: Declaration of Humanity's Corruption",
    "19.14.2": "God's Examination of Humanity",
    "19.14.4": "Iniquity of the Evildoers and Their Rejection",
    "19.14.7": "Anticipation of God's Salvation",
    "19.15.1": "Introduction to the Holy Dwelling",
    "19.15.2": "Characteristics of the Worthy Dweller",
    "19.15.4": "Worthy Dweller's Social Conduct",
    "19.15.5": "Conclusion: Unshakable Assurance",
    "19.16.1": "Introduction and Expression of Trust in God",
    "19.16.3": "Fellowship with God's Righteous People and Respect for Their Beliefs",
    "19.16.5": "Recognition of God's Provision and Sovereignty",
    "19.16.7": "Worship and Gratitude for God's Guidance",
    "19.16.9": "Joy and Confidence in God's Presence",
    "19.16.11": "Eternal Fulfillment and Joy in God's Holy Presence",
    "19.17.1": "Introduction: A Prayer for Vindication",
    "19.17.3": "Affirmation of Integrity",
    "19.17.6": "Petition for Protection",
    "19.17.10": "Description of Wicked Enemies",
    "19.17.13": "Prayer for God's Intervention",
    "19.17.15": "Expression of Confidence and Hope",
    "19.18.1": "Introduction: Title and Praise to God",
    "19.18.4": "The Righteous Cry and God's Response",
    "19.18.20": "The Basis of God's Deliverance",
    "19.18.25": "God's Dealings with People According to Their Character",
    "19.18.30": "God's Mighty Acts of Deliverance",
    "19.18.46": "The Conclusion: Exalting God and Celebrating His Faithfulness",
    "19.19.1": "Introduction: The Glory of God's Creation",
    "19.19.7": "The Perfection of God's Law",
    "19.19.12": "The Psalmist's Prayer for Cleansing and Purity",
    "19.20.1": "Introduction: A prayer of confidence in God",
    "19.20.3": "Petitions and blessings for the king",
    "19.20.6": "Assurance of the Lord's saving power",
    "19.20.9": "Conclusion: A final plea for continued salvation",
    "19.21.1": "Introduction: Praise for the King's Victories",
    "19.21.3": "The King's Relationship with God",
    "19.21.5": "The King's Trust in God's Strength",
    "19.21.8": "God's Judgments Against the Wicked",
    "19.21.11": "A Call to Fear and Praise God",
    "19.22.1": "Introduction: The Forsaken Messiah",
    "19.22.3": "In the Midst of Suffering: Faith and Trust",
    "19.22.6": "The Humiliation and Scorn of the Sufferer",
    "19.22.9": "The Sufferer's Relationship with God since Childhood",
    "19.22.11": "A Plea for God's Help in Distress",
    "19.22.14": "The Physical and Emotional Torment of the Sufferer",
    "19.22.19": "A Final Plea for Deliverance",
    "19.22.22": "The Sufferer's Praise and Proclamation",
    "19.22.28": "Conclusion: The Far-Reaching Impact of the Sufferer's Deliverance",
    "19.23.1": "The Lord as the Shepherd",
    "19.23.4": "The Lord as the Protector and Comforter",
    "19.23.6": "The Lord as the Source of Everlasting Goodness and Mercy",
    "19.24.1": "Introduction: The Earth and its Fullness Belong to the Lord",
    "19.24.3": "Ascending the Holy Hill: The Requirements of Holiness",
    "19.24.7": "The Triumphal Entry of the King of Glory",
    "19.25.1": "Introduction: A prayer for guidance",
    "19.25.3": "Petition for Deliverance",
    "19.25.8": "God as the Instructor",
    "19.25.12": "Assurance of blessings for the godly",
    "19.25.16": "Prayer for personal distress",
    "19.25.19": "Appeal for protection from enemies",
    "19.26.1": "Introduction: A Plea for Divine Judgment on the Righteous Life",
    "19.26.3": "Righteousness Lived Out",
    "19.26.6": "Praise and Thanksgiving for the Lord's Presence",
    "19.26.8": "The Desire for God's Steadfast Love",
    "19.26.11": "Confidence in the Lord's Protection",
    "19.27.1": "Confidence in God's Protection",
    "19.27.4": "Desire for God's Presence",
    "19.27.7": "Prayer for Guidance and Mercy",
    "19.27.10": "Trust in God Despite Being Forsaken",
    "19.27.12": "Prayer for Deliverance From Enemies",
    "19.27.14": "Conclusion: Exhortation to Wait on the Lord",
    "19.28.1": "Introduction - A Cry for Help",
    "19.28.3": "The Wicked and Their Downfall",
    "19.28.6": "Thanksgiving for God's Help",
    "19.28.8": "Praising God as Protector and Savior",
    "19.29.1": "Introduction: The Call to Worship",
    "19.29.3": "Lord's Power and Majesty in the Natural World",
    "19.29.6": "God's Power and Authority Over All Creation",
    "19.29.8": "God's Presence in the Wilderness and Its Effects",
    "19.29.10": "God's Eternal Reign as King and Its Implications",
    "19.30.1": "Introduction: A Psalm of Thankfulness and Praise",
    "19.30.6": "The Confidence in God's Blessing",
    "19.30.8": "The Desperation and Plea for God's Mercy",
    "19.30.11": "The Transformation from Mourning to Joy",
    "19.31.1": "Trust in the Lord as a Refuge",
    "19.31.5": "Dedication of Life to God",
    "19.31.9": "Lamentation and Plea for Relief",
    "19.31.14": "Affirmation of Trust in God",
    "19.31.19": "Praise for God's Goodness and Redemption",
    "19.32.1": "Introduction: A Blessed Life",
    "19.32.3": "The Consequences of Sin",
    "19.32.5": "Confession and Forgiveness",
    "19.32.6": "Trusting in God",
    "19.32.8": "God's Guidance and Instruction",
    "19.32.10": "Contrasting Outcomes",
    "19.33.1": "Introduction: A Call to Praise",
    "19.33.4": "Reasons to Praise the Lord",
    "19.33.13": "God's Watchful Care",
    "19.33.20": "Trust and Hope in the Lord",
    "19.34.1": "A Call to Praise",
    "19.34.4": "Testimony of God's Deliverance",
    "19.34.8": "The Blessings of Seeking God",
    "19.34.11": "Instruction in the Fear of the Lord",
    "19.34.15": "God's Attentiveness to the Righteous and Unrighteous",
    "19.34.19": "God's Deliverance and Redemption",
    "19.35.1": "Invocation and Supplication",
    "19.35.4": "The Oppression and Injustice of the Enemies",
    "19.35.9": "Trust in the Lord and Rejoicing Over Deliverance",
    "19.35.11": "Debating the Unfair Treatment by Enemies",
    "19.35.15": "The Mocking Conduct of the Enemies",
    "19.35.17": "A Cry for God's Justice and Deliverance",
    "19.35.22": "Affirmation of Faith and Confidence in the Lord",
    "19.35.26": "Thanksgiving, Praise, and Testimony to God's Deliverance",
    "19.36.1": "Introduction",
    "19.36.2": "Characteristics of the Unrighteous",
    "19.36.5": "Attributes of God",
    "19.36.10": "Prayer for God's Protection and Mercy",
    "19.36.12": "Final Proclamation",
    "19.37.1": "Introduction: The Theme of Trusting in the Lord",
    "19.37.3": "The Righteous versus the Wicked: The Choice of Lifestyle",
    "19.37.9": "The Inevitable End of the Wicked",
    "19.37.16": "The Blessings of the Righteous",
    "19.37.25": "The Faithfulness of the Lord towards the Righteous",
    "19.37.30": "Wisdom and the Righteous",
    "19.37.34": "The Final Comparison of the Wicked and Righteous",
    "19.38.1": "Introduction: Plea for Mercy",
    "19.38.3": "Personal Affliction: Description of Spiritual and Physical Suffering",
    "19.38.9": "Personal Isolation: Rejection by Friends and Adversaries",
    "19.38.13": "Personal Response: Trust and Dependence on God",
    "19.38.17": "Confession and Repentance: Acknowledgment of Sin",
    "19.38.21": "Conclusion: Plea for God's Help and Redemption",
    "19.39.1": "Introduction: Awareness of Frailty",
    "19.39.4": "Contemplating the Brevity of Life",
    "19.39.7": "Prayer for Deliverance",
    "19.39.12": "Closing Appeal: A Cry for Compassion",
    "19.40.1": "Introduction: Praises for God's Deliverance",
    "19.40.4": "Thanksgiving for God's Righteousness and Steadfast Love",
    "19.40.6": "The Sacrifice of Obedience and Transformation",
    "19.40.9": "Proclaiming God's Goodness and Faithfulness",
    "19.40.11": "Supplication for God's Continued Help and Protection",
    "19.40.13": "Praying for the Defeat of Evil Enemies",
    "19.40.16": "Final Praise and Blessings for God's Salvation",
    "19.41.1": "Introduction and Blessing for the Compassionate",
    "19.41.4": "David's Personal Struggles and Plea for Mercy",
    "19.41.11": "Confidence in God's Favor and Vindication",
    "19.41.13": "Conclusion and Doxology",
    "19.42.1": "Longing for God in the Midst of Distress",
    "19.42.5": "Hope in the Face of Despair",
    "19.42.9": "Renewed Lament and Hope",
    "19.43.1": "Introduction: A Plea for Deliverance and Vindication",
    "19.43.2": "The Psalmist's Intimate Dialogue with God",
    "19.43.4": "The Resolution to Worship and Praise",
    "19.43.5": "The Psalmist's Self-Admonition and Call to Hope",
    "19.44.1": "Introduction: Confidence in God's Help",
    "19.44.4": "Faith Declared: Trust in God for Deliverance",
    "19.44.9": "Lamentation: Suffering Despite Righteousness",
    "19.44.17": "Innocent Plea: Assertion of Loyalty to God",
    "19.44.23": "Divine Intervention: A Call for God's Rescue",
    "19.45.1": "Introduction: Praise to the King",
    "19.45.3": "The King's Might and Conquests",
    "19.45.6": "The Divine Throne and Righteous Rule",
    "19.45.8": "The King's Splendor and Luxury",
    "19.45.10": "The Bride's Call to Loyalty and submission",
    "19.45.13": "The Bride's Entrance and Beauty",
    "19.45.16": "The Future Royal Lineage",
    "19.46.1": "Introduction: The Powerful and Loving God",
    "19.46.2": "The Peaceful City of God",
    "19.46.4": "The River of God's Presence",
    "19.46.6": "God's Sovereignty in the Midst of Turmoil",
    "19.46.8": "Witnessing the Works of the Lord",
    "19.46.10": "The Call to Be Still and Acknowledge God",
    "19.46.11": "Reaffirming God's Protection",
    "19.47.1": "Introduction: Call to Praise God",
    "19.47.3": "God's Supreme Power and Reign",
    "19.47.5": "Celebration of God's Kingship",
    "19.47.8": "Assurance of God's Reign over All",
    "19.48.1": "Praise to the Lord and Zion",
    "19.48.4": "The Lord's Defense of Zion",
    "19.48.9": "Meditation on God's Steadfast Love and Faithfulness",
    "19.48.12": "Encouragement to Walk Through and Tell of Zion's Glory",
    "19.49.1": "Introduction: The Universality and Importance of the Message",
    "19.49.5": "The Challenge of Wealth and Mortality",
    "19.49.13": "The Fate of the Foolish Wealthy",
    "19.50.1": "Introduction: God's Call to Worship",
    "19.50.7": "The Righteous and their sacrifices",
    "19.50.16": "The Wicked and their deeds",
    "19.50.21": "God's Warning and Final Judgment",
    "19.51.1": "Introduction: A Plea for Mercy and Forgiveness",
    "19.51.3": "Acknowledgment of Sin and Guilt",
    "19.51.7": "Prayer for Renewal and Restoration",
    "19.51.13": "Commitment to Praise and Teach",
    "19.51.16": "True Repentance and Sacrifice",
    "19.51.18": "Petition for Favor and Prosperity of Zion",
    "19.52.1": "The Arrogance of the Wicked",
    "19.52.4": "God's Response to the Wicked",
    "19.52.6": "Righteous Spectators",
    "19.52.8": "The Faith of the Righteous",
    "19.53.1": "Introduction: The Foolishness of Denying God",
    "19.53.2": "The Depravity of Humanity",
    "19.53.4": "The Consequences of Sin",
    "19.53.6": "The Cry for Salvation",
    "19.54.1": "Introduction: Prayerful Cry for Deliverance",
    "19.54.3": "Appeal for Protection from Oppressors",
    "19.54.4": "Confidence in God's Support and Vindication",
    "19.54.6": "Expression of Gratitude for God's Deliverance",
    "19.55.1": "Introduction: A Cry for Help",
    "19.55.4": "The Betrayal by a Trusted Friend",
    "19.55.9": "The Corruption and Deceit in the City",
    "19.55.12": "The Broken Bond of Friendship",
    "19.55.16": "Assurance in God's Help",
    "19.55.20": "The False Friend's Fate and the Faithful's Resolution",
    "19.56.1": "Trust in God Amidst Persecution",
    "19.56.3": "Keeping Faith in God's Protection",
    "19.56.5": "The Continuous Plots of Oppressors",
    "19.56.8": "Acknowledgment of God's Sovereignty",
    "19.56.10": "Rejoicing in God's Deliverance",
    "19.56.12": "Gratitude for God's Help",
    "19.57.1": "Introduction: Prayer for Refuge",
    "19.57.3": "Personal Distress amidst Adversaries",
    "19.57.5": "Confidence in God's Exaltation",
    "19.57.7": "Commitment to Praise and Worship",
    "19.57.11": "Conclusion: Acknowledgment of God's Glory",
    "19.58.1": "Introduction",
    "19.58.3": "Evils of the Wicked",
    "19.58.6": "Judgment Against the Wicked",
    "19.58.10": "Righteousness Triumphs",
    "19.59.1": "Introduction",
    "19.59.3": "Wrongful Persecution Described",
    "19.59.5": "Appeal for God's Intervention",
    "19.59.6": "Comparing Enemies to Wild Animals",
    "19.59.8": "Confidence in God as a Stronghold",
    "19.59.11": "The Desire for Deferred Judgment",
    "19.59.14": "A Song of Praise",
    "19.59.16": "Trust and Exaltation of the Lord",
    "19.60.1": "Introduction: A Cry for God's Help",
    "19.60.4": "God's Promised Victory",
    "19.60.9": "Confident Appeal for God's Presence and Assistance",
    "19.61.1": "Longing for God's Protection",
    "19.61.3": "Trust in God's Faithful Care",
    "19.61.5": "Assurance of God's Everlasting Presence",
    "19.61.7": "Praise for God's Trustworthiness",
    "19.62.1": "Introduction: Confidence in God Alone",
    "19.62.3": "Adversaries and Their Deceitful Actions",
    "19.62.5": "Reaffirmation of Trust in God",
    "19.62.9": "Contrast Between God's Power and Human Weakness",
    "19.62.11": "Conclusion: God's Strength and Loving Kindness",
    "19.63.1": "Longing for God",
    "19.63.2": "Beholding God's Power and Glory",
    "19.63.5": "Meditating on God during the Night",
    "19.63.7": "Trusting in God while under Threat",
    "19.63.9": "God's Judgment on the Wicked",
    "19.63.11": "Rejoicing in God's Victory",
    "19.64.1": "Introduction: A Cry for Protection",
    "19.64.2": "The Wicked's Evil Plans",
    "19.64.5": "The Sinister Schemes of the Wicked",
    "19.64.7": "God's Decisive Response to the Wicked",
    "19.64.10": "Righteous Rejoicing in God's Judgment",
    "19.65.1": "Praise and Thanksgiving for God's Righteousness",
    "19.65.5": "God's Power in Creation",
    "19.65.9": "God's Provision and Care for the Earth",
    "19.66.1": "Introduction: A Call to Praise God for His Awesome Works",
    "19.66.5": "Remembering God's Mighty Acts in History",
    "19.66.8": "Thanksgiving for God's Faithful Care",
    "19.66.13": "The Psalmist's Personal Vow to Offer Praise and Sacrifice",
    "19.66.16": "Proclaiming the Goodness of God",
    "19.66.20": "Conclusion: Final Praise to God for His Love",
    "19.67.1": "Introduction: A Call for God's Blessing",
    "19.67.3": "Response of the Nations to God's Blessing",
    "19.67.6": "God's Continued Blessings and Worldwide Praise",
    "19.68.1": "Introduction: An Appeal to God's Strength",
    "19.68.4": "God's Care for Israel",
    "19.68.7": "God's Greatness in Israel's Journey",
    "19.68.11": "God's Protection in Battle",
    "19.68.15": "God's Presence on Zion",
    "19.68.19": "Praise to God for His Deliverance",
    "19.68.24": "God's Majestic Procession",
    "19.68.28": "God's Blessings on the Righteous",
    "19.68.32": "The Universal Worship of God",
    "19.69.1": "The Psalmist's Cry for Help",
    "19.69.5": "The Psalmist's Confession and Appeal",
    "19.69.13": "The Psalmist's Prayer for Deliverance",
    "19.69.19": "The Psalmist's Plea for Divine Judgment",
    "19.69.29": "The Psalmist's Praise and Vow",
    "19.70.1": "Introduction: Prayer for Deliverance",
    "19.70.2": "Petition for Swift Intervention from God",
    "19.70.4": "Rejoicing and Praise for the Righteous",
    "19.70.5": "Personal Plea for Salvation and Assistance",
    "19.71.1": "Introduction: A Prayer for Refuge and Deliverance",
    "19.71.4": "The Psalmist's Lifelong Praise and Trust in God",
    "19.71.9": "The Psalmist's Appeal for God's Help in Old Age",
    "19.71.14": "Expected Deliverance and Future Praise",
    "19.71.19": "Thanksgiving for God's Righteousness and Everlasting Support",
    "19.72.1": "Introduction: A Prayer for the King",
    "19.72.2": "The King's Leadership and Qualities",
    "19.72.8": "The Extent of the King's Reign",
    "19.72.12": "The King's Compassion and Care for His People",
    "19.72.15": "The Prosperity and Blessings Under the King's Reign",
    "19.72.18": "Conclusion: Praise to God and End of Prayers",
    "19.73.1": "Introduction: The Psalmist's Struggle",
    "19.73.4": "Description of the Wicked's Prosperity",
    "19.73.13": "The Psalmist's Internal Struggle",
    "19.73.17": "The Turning Point: Reflecting in God's Sanctuary",
    "19.73.21": "The Psalmist's Repentance and Renewed Relationship with God",
    "19.73.27": "Conclusion: Praising God and Declaring His Deeds",
    "19.74.1": "Introduction",
    "19.74.4": "The Destruction of the Sanctuary",
    "19.74.9": "The Lament over God's Absence",
    "19.74.12": "The Affirmation of God's Mighty Deeds",
    "19.74.18": "The Plea for God's Intervention",
    "19.75.1": "Introduction: Gratitude for God's Wondrous Deeds",
    "19.75.4": "Warning Against Boasting and Arrogance",
    "19.75.9": "Resolute Praise and Commitment",
    "19.76.1": "Introduction: God's Mighty Presence",
    "19.76.4": "God's Powerful Judgment",
    "19.76.7": "God's Overwhelming Sovereignty",
    "19.76.11": "Giving Praise and Glory to God",
    "19.77.1": "Introduction: Cry for Help",
    "19.77.3": "Reflections on Sleepless Nights",
    "19.77.7": "Recalling God's Past Faithfulness",
    "19.77.11": "Meditations on God's Wondrous Works",
    "19.77.13": "God's Control Over Nature",
    "19.77.16": "God's Power Displayed in the Miracle at the Red Sea",
    "19.78.1": "Introduction: The Purpose of the Psalm and Importance of Remembering God's Works",
    "19.78.9": "Israel's History of Rebellion and Unfaithfulness",
    "19.78.42": "God's Deliverance of Israel from Egypt and Demonstrations of Power",
    "19.78.56": "Israel's Continued Rebellion, Idolatry, and Punishment",
    "19.79.1": "Introduction",
    "19.79.2": "Lament over the destruction of Jerusalem",
    "19.79.5": "Prayer for God's intervention",
    "19.79.7": "Plea for forgiveness and salvation",
    "19.79.10": "Prayer for justice and retribution",
    "19.79.13": "Commitment to God's praise",
    "19.80.1": "Introduction: A Cry for Restoration",
    "19.80.4": "Lamentation over Israel's Afflictions",
    "19.80.8": "The Vineyard Parable and Israel's History",
    "19.80.17": "The Hope for Restoration",
    "19.81.1": "Introduction: Exhortation to Worship",
    "19.81.4": "The Reason for Praise: God's Deliverance of Israel",
    "19.81.8": "God's Desire for Israel's Obedience and Loyalty",
    "19.81.11": "Israel's Disobedience and its Consequences",
    "19.81.13": "Promises of Blessings for Repentant Israel",
    "19.82.1": "Introduction: Call to the Divine Council",
    "19.82.2": "Rebuke of the Unjust Rulers",
    "19.82.5": "Consequences of the Rulers' Failure",
    "19.82.8": "Appeal for Divine Judgment",
    "19.83.1": "Introduction: A Cry for God's Intervention",
    "19.83.3": "The Unholy Alliance against God's People",
    "19.83.9": "Historical Examples of Divine Judgment",
    "19.83.13": "The Prayer for Vengeance and Confusion",
    "19.83.18": "Conclusion: God's Sovereignty and Praise",
    "19.84.1": "Longing for God's Presence",
    "19.84.5": "Strength and Joy in the Journey toward God's Presence",
    "19.84.9": "Trusting in God's Protection and Blessings",
    "19.85.1": "Supplication for God's favor",
    "19.85.4": "Prayer for the restoration of God's presence",
    "19.85.8": "The anticipated manifestation of God's loving-kindness",
    "19.86.1": "Introduction: Plea for God's Mercy",
    "19.86.3": "David's Confidence in God's Faithfulness",
    "19.86.5": "God's Loving-kindness and Willingness to Forgive",
    "19.86.8": "Acknowledgement of God's Unique Nature",
    "19.86.11": "David's Desire for an Obedient Heart",
    "19.86.13": "A Cry for Deliverance from the Enemy",
    "19.86.15": "Assurance in the Nature of God's Compassion",
    "19.86.17": "Conclusion: David's Anticipation of God's Favor",
    "19.87.1": "Introduction: Glorious Praise of Zion",
    "19.87.2": "The Sacred City: The City of God",
    "19.87.4": "The Nations' Acknowledgment of Zion",
    "19.87.6": "The Divine Record: People Registered as Zion's Citizens",
    "19.87.7": "The Cultural Richness of Zion: Joyful Singing and Dancing",
    "19.88.1": "An appeal for help in affliction",
    "19.88.6": "Feeling forsaken by God",
    "19.88.10": "A plea for God's intervention",
    "19.88.13": "A persistent cry for help",
    "19.88.16": "Suffering under God's wrath and abandonment",
    "19.89.1": "Introduction: God's Covenant with David",
    "19.89.5": "God's Majesty and Sovereignty",
    "19.89.15": "Blessings of God's People",
    "19.89.19": "The Lord's Choice of David",
    "19.89.30": "Consequences of Disobedience",
    "19.89.46": "Plea for God's Restoration and Mercy",
    "19.90.1": "Introduction: Acknowledging God as the Eternal Refuge",
    "19.90.3": "The Transience of Human Life in Contrast to God's Eternity",
    "19.90.7": "The Reality of Human Suffering and Sin",
    "19.90.12": "A Prayer for Wisdom, Compassion, and God's Favor",
    "19.91.1": "Introduction: Assurance of Refuge",
    "19.91.2": "Confidence in Divine Protection",
    "19.91.3": "Protection from Troubles and Dangers",
    "19.91.7": "Protection for the Righteous",
    "19.91.9": "Trusting in the Lord's Protection",
    "19.91.13": "Victory over Enemies and Dangers",
    "19.91.14": "The Lord's Promise of Help and Salvation",
    "19.92.1": "Introduction: Praising the Lord for His Goodness",
    "19.92.4": "God's Works and Thoughts",
    "19.92.7": "The Fate of the Wicked",
    "19.92.10": "God's Protection and Blessings for the Righteous",
    "19.92.13": "The Righteous Flourishing",
    "19.92.15": "Conclusion: Proclaiming God's Righteousness and Faithfulness",
    "19.93.1": "The Majesty of God's Reign",
    "19.93.2": "The Certainty of God's Creation",
    "19.93.3": "The Power of God Over the Waters",
    "19.93.5": "The Holiness of God's House",
    "19.94.1": "Introduction: The Call for Vengeance",
    "19.94.3": "God's Timing and Judgment",
    "19.94.8": "A Warning to the Foolish and Wicked",
    "19.94.12": "The Blessedness of God's Chastisement",
    "19.94.16": "The Lord as Refuge and Support",
    "19.94.20": "Final Condemnation of the Wicked",
    "19.95.1": "Introductory Call to Worship",
    "19.95.3": "Reasons for Worship",
    "19.95.6": "Submission to God and Worship",
    "19.95.8": "Warning Against Disobedience",
    "19.96.1": "Call to Worship the Lord",
    "19.96.4": "The Supreme Glory of the Lord",
    "19.96.7": "Nations Invited to Pay Honors to the Lord",
    "19.96.10": "Proclaim the Lord's Reign",
    "19.96.13": "The Coming of the Lord in Judgment",
    "19.97.1": "Introduction: The Majesty and Sovereignty of God",
    "19.97.3": "The Power and Glory of God",
    "19.97.7": "God Defending His People",
    "19.97.10": "Exhortation to the Righteous",
    "19.98.1": "Introduction: Singing to the Lord for His Victories",
    "19.98.2": "God's Salvation Revealed in His Justice",
    "19.98.4": "Universal Praise for God's Supremacy",
    "19.98.7": "Creation's Response to God's Sovereignty",
    "19.98.9": "The Lord's Rule and Coming Judgment",
    "19.99.1": "Introduction: Proclaiming the Reign of the LORD",
    "19.99.2": "The Majesty and Holiness of God",
    "19.99.4": "The Foundation of God's Rule",
    "19.99.6": "The Heritage of God's People",
    "19.99.8": "The Faithfulness and Forgiveness of the LORD",
    "19.99.9": "Concluding Call to Worship",
    "19.100.1": "Call to worship",
    "19.100.3": "Acknowledging God's sovereignty",
    "19.100.4": "Entering God's presence with thanksgiving",
    "19.100.5": "Proclaiming God's goodness",
    "19.101.1": "Introduction: A Psalm of Praise and Commitment",
    "19.101.3": "Rejecting Evil",
    "19.101.5": "Associating with the Righteous",
    "19.101.7": "Eliminating Wickedness from the Kingdom",
    "19.102.1": "Introduction: A Prayer of the Afflicted",
    "19.102.3": "The Psalmist's Lament and Suffering",
    "19.102.12": "The Eternality and Mercy of God",
    "19.102.18": "The Future Restoration of Zion",
    "19.102.23": "The Fragility of Human Life and God's Eternal Nature",
    "19.103.1": "Praise for God's Tender Mercies",
    "19.103.6": "God's Compassionate Character",
    "19.103.15": "The Frailty of Human Life and the Everlasting Nature of God's Love",
    "19.103.19": "The Universal Call to Praise the Lord",
    "19.104.1": "Praise for the Creator's Majesty and Wisdom",
    "19.104.5": "The Beauty and Order of God's Creation",
    "19.104.19": "The Interdependence of God's Creatures",
    "19.104.25": "The Vastness and Mystery of God's Creation",
    "19.104.31": "The Role of Humanity in Praising and Preserving God's Creation",
    "19.105.1": "Introduction: Gratitude and Praise for God's Wondrous Works",
    "19.105.6": "God's Covenant with Abraham",
    "19.105.12": "God's Providence During Israel's Wandering in Canaan",
    "19.105.25": "God's Miraculous Plagues in Egypt",
    "19.105.39": "God's Guidance and Provision in the Wilderness",
    "19.106.1": "Introduction: Praise to the Lord",
    "19.106.6": "Israel's History of Sin and God's Deliverance",
    "19.106.47": "Closing Prayer for Restoration and Praise",
    "19.107.1": "Introduction: Thanksgiving for God's Steadfast Love",
    "19.107.4": "God's Deliverance of Wanderers in the Wilderness",
    "19.107.10": "God's Deliverance of Prisoners from Darkness",
    "19.107.17": "God's Healing of the Sick and Afflicted",
    "19.107.23": "God's Help for Seafarers in the Stormy Sea",
    "19.107.33": "God's Providence Over the Changing Fortunes of People",
    "19.107.43": "Conclusion: The Wisdom of God's Powerful Works",
    "19.108.1": "Introduction",
    "19.108.3": "Joyful Proclamation of God's Faithfulness",
    "19.108.6": "God's Sovereignty over the Nations",
    "19.108.10": "The Need for God's Assistance",
    "19.108.12": "Reliance on God's Strength",
    "19.109.1": "Introduction",
    "19.109.6": "Curses for the Wicked",
    "19.109.16": "Implications of the Wicked's Actions",
    "19.109.21": "Prayer for Vindication",
    "19.109.30": "Declaration of Praise",
    "19.110.1": "Introduction: Declaration of Divine Enthronement",
    "19.110.2": "The Messiah's Reign",
    "19.110.4": "The Messiah as Eternal Priest",
    "19.110.5": "The Messiah's Victorious Judgment",
    "19.111.1": "Introduction: The Praise to the Lord",
    "19.111.2": "The Great Works of God",
    "19.111.5": "The Gracious God Provides and Empowers His People",
    "19.111.7": "The Righteousness and Justice of God's Commands",
    "19.111.9": "The Redemption and Covenant of the Lord",
    "19.111.10": "Reverence and Wisdom in the Fear of the Lord",
    "19.112.1": "The Blessings upon the Godly Person",
    "19.112.4": "The Righteousness of the Godly Person",
    "19.112.6": "The Stability of the Godly Person",
    "19.112.5": "Generosity and Compassion of the Godly Person",
    "19.112.7": "The Confidence of the Godly Person",
    "19.112.10": "The Displeasure of the Enemies of the Godly Person",
    "19.113.1": "Introduction: Praise the Lord's Name",
    "19.113.2": "Universal Praise",
    "19.113.4": "The Majesty and Condescension of God",
    "19.113.7": "God Elevates the Lowly",
    "19.113.9": "Conclusion: Reaffirmation of Praise",
    "19.114.1": "Introduction: Celebration of God's Deliverance",
    "19.114.2": "God's Power over Nature",
    "19.114.7": "God's Command over Earth and Water",
    "19.114.9": "Conclusion: Praise and Honor to the Sovereign Lord",
    "19.115.1": "Praise and Glory to the Living God",
    "19.115.4": "The Folly of Idolatry",
    "19.115.9": "Confidence in the Lord",
    "19.115.12": "The Blessings of Trusting in God",
    "19.115.16": "The Power of God in Heaven and Earth",
    "19.115.17": "The Destiny of the Dead Without God",
    "19.116.1": "Introduction: A Psalmist's Love for the Lord",
    "19.116.3": "Divine Rescue in the Face of Death",
    "19.116.7": "The Psalmist's Testimony of Peace and Rest",
    "19.116.9": "The Psalmist's Focus on Serving God in the Land of the Living",
    "19.116.12": "Grateful Response to God's Benevolence",
    "19.116.15": "The Value and Preciousness of God's Servants",
    "19.116.16": "Dedication to a Life of Servitude",
    "19.116.18": "Public Proclamation of God's Goodness",
    "19.117.1": "All Nations Called to Praise",
    "19.118.1": "Introduction: The Faithfulness and Enduring Love of God",
    "19.118.5": "The Psalmist's Personal Testimony of God's Deliverance",
    "19.118.15": "Thanksgiving for the Victory and Deliverance",
    "19.118.22": "The Stone That Became the Cornerstone",
    "19.118.24": "The Day of Celebration and Blessings",
    "19.119.1": "Aleph: Blessedness of the Law-Abiding",
    "19.119.9": "Beth: The Cleansing Effect of God's Word",
    "19.119.17": "Gimel: Divine Guidance Sought and Celebrated",
    "19.119.25": "Daleth: Reviving the Soul with God's Word",
    "19.119.33": "He: Praying for Instruction and Understanding",
    "19.119.41": "Waw: Trusting and Proclaiming God's Promises",
    "19.119.49": "Zayin: Finding Comfort in God's Statutes",
    "19.119.57": "Heth: Renewed Commitment and Gratitude for God's Law",
    "19.119.65": "Teth: God's Discipline and the Value of His Word",
    "19.119.73": "Yodh: Upholding the Testimonies of God",
    "19.119.81": "Kaph: Longing and Trust in Times of Trial",
    "19.119.89": "Lamedh: The Eternity and Sufficiency of God's Word",
    "19.119.97": "Mem: The Sweetness and Wisdom of God's Commandments",
    "19.119.105": "Nun: God's Word as a Guiding Light",
    "19.119.113": "Samekh: Strength and Preservation Through Obedience",
    "19.119.121": "Ayin: Desiring Justice and Hating Falsehood",
    "19.119.129": "Pe: Enlightened and Grieved by God's Word",
    "19.119.137": "Tsadhe: Holiness and Righteousness of God's Commandments",
    "19.119.145": "Qoph: Calling Out to God with Wholehearted Devotion",
    "19.119.153": "Resh: Deliverance and Mercy Through God's Word",
    "19.119.161": "Shin: Peace and Joy in God's Word Despite Persecution",
    "19.119.169": "Taw: Petition for Guidance and Protection as God's Servant",
    "19.120.1": "Introduction: A Call for Help",
    "19.120.2": "The Psalmist's Suffering: Lies and Deceit",
    "19.120.5": "Living Among Hostile People",
    "19.120.7": "Seeking Peace in a Hostile World",
    "19.121.1": "Seeking Help from the Lord",
    "19.121.3": "God as Our Ever-Watchful Protector",
    "19.121.7": "The Lord's Comprehensive Protection",
    "19.122.1": "Introduction: A Song of Ascents",
    "19.122.2": "Description of Jerusalem",
    "19.122.6": "Prayer for Jerusalem",
    "19.123.1": "Supplication:",
    "19.123.3": "Request for Mercy:",
    "19.123.4": "Endurance in the Midst of Contempt:",
    "19.124.1": "Introduction: A Song of Ascent",
    "19.124.2": "The Lord as Israel's Protector",
    "19.124.6": "Gratitude for Divine Deliverance",
    "19.124.8": "Conclusion: Dependence on the Lord",
    "19.125.1": "Trust in the Lord as the Steadfast Foundation",
    "19.125.2": "God's Protection and Presence",
    "19.125.3": "Righteousness and Peace for God's People",
    "19.125.4": "Prayers for the Faithful and Righteous",
    "19.125.5": "The Separation of Good and Evil",
    "19.126.1": "Remembrance of Past Deliverance",
    "19.126.3": "The Request for Present Renewal",
    "19.126.5": "Descriptive Metaphors for Restoration",
    "19.127.1": "The Futility of Human Efforts without the Lord's Blessing",
    "19.127.3": "The Blessing of Children as a Gift from the Lord",
    "19.128.1": "Blessings for Those Who Fear the Lord",
    "19.128.3": "The Blessings of Family Life",
    "19.128.5": "The Promise of God's Blessings and Well-being",
    "19.129.1": "The Perseverance of Israel",
    "19.129.3": "The Plight of the Oppressors",
    "19.129.5": "The Curse on the Wicked",
    "19.129.8": "The Declaration of Confidence",
    "19.130.1": "Opening Cry for Mercy",
    "19.130.3": "Recognition of God's Forgiveness",
    "19.130.5": "Waiting and Hoping in the Lord",
    "19.130.7": "Call to the People to Hope in God's Redemption",
    "19.131.1": "Assertion of Humility",
    "19.131.2": "Comparison to a Weaned Child",
    "19.131.3": "Encouragement to Trust in the Lord",
    "19.132.1": "Introduction: A Song in Honor of God's Faithfulness",
    "19.132.3": "David's Passion for God's House",
    "19.132.6": "Pilgrimage to Worship and the Discovery of the Ark",
    "19.132.11": "God's Promises to David and Zion",
    "19.133.1": "The Blessing of Unity",
    "19.134.1": "Exhortation to Nightly Worship",
    "19.134.3": "Assurance of God's Blessing",
    "19.135.1": "Call to Praise God",
    "19.135.5": "The Greatness of God",
    "19.135.13": "The Lord's Name and Eternal Dominion",
    "19.135.15": "The Vanity of Idols",
    "19.135.19": "Benediction and Final Call to Praise",
    "19.136.1": "Introduction and Exhortations to Praise",
    "19.136.4": "The Celebration of God's Creation and Guidance",
    "19.136.10": "The Lord's Mighty Acts in Israel's History",
    "19.136.23": "God's Everlasting Mercy and Steadfast Love",
    "19.137.1": "Lamentation Over the Exile",
    "19.137.5": "Vow to Never Forget Jerusalem",
    "19.137.7": "Judgment on their Captors",
    "19.138.1": "Thanksgiving and Praise for God's Faithfulness and Mercy",
    "19.138.4": "God's Sovereignty and Guidance to All Nations",
    "19.138.7": "God's Protection and Deliverance in Times of Trouble",
    "19.139.1": "Introduction: Declaration of God's Perfect Knowledge",
    "19.139.7": "God's Omnipresence: There is No Escape",
    "19.139.13": "God's Creativity: The Formation of Life",
    "19.139.17": "God's Thoughts: Innumerable and Precious",
    "19.139.19": "God's Justice: A Plea for Vindication",
    "19.139.23": "Conclusion: An Invitation for God's Examination",
    "19.140.1": "Introduction: Prayer for Deliverance from Evil People",
    "19.140.3": "Description of the Wicked",
    "19.140.6": "Prayer for Safety and God's Intervention",
    "19.140.9": "The Fate of the Evil",
    "19.140.12": "Trust in God's Justice and Righteousness",
    "19.140.14": "Conclusion: A Song of Praise",
    "19.141.1": "Introduction: Call for Divine Help",
    "19.141.3": "Petition for Protection from Evil",
    "19.141.5": "The Righteous as Corrective Agents",
    "19.141.6": "The Fate of the Wicked",
    "19.141.8": "Reliance on God's Protection",
    "19.142.1": "Introduction: A Cry for Help",
    "19.142.2": "David's Desperation and Trust in God",
    "19.142.4": "Finding Solace in God Amidst Loneliness",
    "19.142.5": "David's Declaration of Dependence on God",
    "19.142.6": "David's Prayer for Deliverance",
    "19.143.1": "Invocation and Lament",
    "19.143.5": "Meditation on God's Past Acts and the Psalmist's Thirst for God",
    "19.143.7": "Petitions for Deliverance and Guidance",
    "19.143.11": "Prayer for the Preservation of Life and the Defeat of Enemies",
    "19.144.1": "Invocation and Praise",
    "19.144.3": "Meditation on Human Frailty and Divine Involvement",
    "19.144.5": "Prayer for God's Intervention and Protection",
    "19.144.9": "The Promise of Exaltation and Prosperity",
    "19.144.12": "Celebration of National Blessings and Prosperity",
    "19.145.1": "Introduction: Praise and Exaltation",
    "19.145.3": "The Greatness of God",
    "19.145.8": "The Lord's Grace and Compassion",
    "19.145.10": "The Glory of God's Kingdom",
    "19.145.14": "The Lord's Support and Provision",
    "19.145.17": "The Lord's Righteousness and Kindness",
    "19.145.21": "Conclusion: Praise and Proclamation of God's Name",
    "19.146.1": "Praise for God's Faithfulness and Enduring Love",
    "19.146.3": "Warning against Trusting in Mere Mortals",
    "19.146.5": "Encouragement to Place Trust in God",
    "19.146.7": "God's Care for the Vulnerable and Oppressed",
    "19.146.10": "The Everlasting Reign of God",
    "19.147.1": "Praise for God's Power, Care, and Providence",
    "19.147.7": "God's Sovereignty Over Nature",
    "19.147.12": "God's Blessings Upon Jerusalem and His People",
    "19.147.15": "Praise for God's Word and Commandments",
    "19.147.19": "Praise for God's Exclusive Relationship with Israel",
    "19.148.1": "Call for Praise from the Heavens",
    "19.148.7": "Call for Praise from the Earth",
    "19.148.13": "A Unifying Praise of the Lord",
    "19.149.1": "Praise to God for His salvation and Judgment",
    "19.149.5": "Praise and Worship through Action",
    "19.149.7": "God's People as His Instruments of Judgment",
    "19.150.1": "Introduction: Call to Praise",
    "19.150.2": "Reasons to Praise God",
    "19.150.5": "Universal Praise",
    "19.150.6": "Conclusion: Praise from All of Creation",
    "20.1.1": "Title and Purpose",
    "20.1.3": "Benefits of Proverbs",
    "20.1.7": "Foundation of Wisdom",
    "20.1.8": "Warnings against Evil Companions",
    "20.1.20": "Wisdom's Call",
    "20.2.1": "Benefits of Wisdom",
    "20.3.1": "Trust in the Lord",
    "20.3.13": "Wisdom's Value",
    "20.4.1": "Path to Wisdom",
    "20.5.1": "Avoid Sexual Immorality",
    "20.6.1": "Wisdom vs. Folly",
    "20.6.6": "Warnings against Laziness",
    "20.6.12": "Warnings against Mischief",
    "20.6.20": "Warnings against Adultery",
    "20.7.1": "The Call of Wisdom",
    "20.8.1": "Wisdom's Invitation",
    "20.8.22": "Wisdom's Foundation",
    "20.9.1": "Accepting Wisdom",
    "20.10.1": "Righteousness vs. Wickedness",
    "20.11.1": "Speech, Friendships, and Wealth",
    "20.12.1": "Trusting in the Lord",
    "20.13.1": "Diligence and Laziness",
    "20.14.1": "Wise Living",
    "20.15.1": "Fools and Wise People",
    "20.16.1": "Discipline and Character",
    "20.17.1": "Justice and Integrity",
    "20.18.1": "Conflict and Relationships",
    "20.19.1": "Speech and Anxieties",
    "20.20.1": "Wisdom, Foolishness, and Relationships",
    "20.21.1": "Rulers, Servants, and Honesty",
    "20.22.1": "Wise Sayings",
    "20.22.17": "Instructions for Life",
    "20.22.22": "Sayings on Righteousness and Justice",
    "20.23.1": "Seek Wisdom",
    "20.23.13": "Parental Instructions",
    "20.23.29": "Warnings",
    "20.24.1": "Seeking Wisdom",
    "20.24.8": "Judgments and Fairness",
    "20.24.13": "Reward and Retribution",
    "20.24.21": "Wisdom's Rewards",
    "20.24.23": "Wisdom in Judgment",
    "20.24.30": "Laziness and Destruction",
    "20.25.1": "Dealing with Kings and Neighbors",
    "20.25.21": "Dealing with Enemies",
    "20.27.1": "Wise Sayings",
    "20.29.1": "Righteousness, Justice, and Trust",
    "20.30.1": "An Introduction to Agur",
    "20.30.10": "Proverbs on Animals",
    "20.30.32": "Sayings on Human Behavior",
    "20.31.1": "Introduction to Lemuel",
    "20.31.2": "Ethical Instructions",
    "20.31.10": "The Model Wife",
    "20.31.28": "Praise for the Virtuous Woman",
    "21.1.1": "Title of the Book",
    "21.1.2": "Vanity of Vanities",
    "21.1.4": "The Futility of Transience",
    "21.1.12": "Pursuit of Wisdom",
    "21.1.16": "The Limitations of Wisdom",
    "21.2.1": "The Test of Pleasures and Possessions",
    "21.2.12": "Wisdom and Folly: A Comparison",
    "21.2.17": "The Vanity of Labor",
    "21.2.24": "The God-Given Roles of Work and Enjoyment",
    "21.3.1": "A Time for Every Purpose",
    "21.3.9": "God's Eternal Time and Human Time",
    "21.3.16": "The Injustice of Human Judgment",
    "21.4.1": "Oppression and Injustice",
    "21.4.4": "Envy and Achievement",
    "21.4.7": "The Folly of Selfish Toil",
    "21.4.13": "The Futility of Political Power",
    "21.5.1": "Proper Attitude Toward God",
    "21.5.8": "Wealth and Contentment",
    "21.5.18": "Enjoying Life as a Gift from God",
    "21.6.1": "The Futility of Possessions",
    "21.6.7": "The Inability to Satisfy Desire",
    "21.6.10": "The Unknowable Future",
    "21.7.1": "Proverbs on Wisdom",
    "21.7.15": "The Paradox of Wickedness and Righteousness",
    "21.7.19": "The Folly of Extremes",
    "21.7.25": "Women, Wisdom, and Folly",
    "21.8.1": "Wisdom in Dealing with Authorities",
    "21.8.6": "The Limitations of Human Wisdom",
    "21.8.10": "The Mystery of Divine Justice",
    "21.8.16": "Incomprehensibility of God's Ways",
    "21.9.1": "The Uncertainty of Life and Death",
    "21.9.13": "Wisdom and Providence in Human Life",
    "21.10.1": "The Contrast of Wisdom and Folly",
    "21.10.8": "Wisdom and Folly in Work",
    "21.10.16": "Wisdom in Ruling",
    "21.11.1": "Be Generous: Enjoy Life",
    "21.11.7": "Savor Youth and Remember God",
    "21.12.1": "The Aging Process and the Need to Remember God",
    "21.12.9": "The Wise Teacher and His Advice",
    "21.12.13": "The Sum of All Matters: Fear God and Keep His Commandments",
    "22.1.1": "Title: Solomon's Song of Songs",
    "22.1.2": "The Shulamite's Longing for Her Beloved",
    "22.1.5": "The Shulamite's Insecurities and Praise",
    "22.1.8": "The Beloved's Encouragement and Praise of the Shulamite",
    "22.1.12": "The Shulamite's Love and Fragrance",
    "22.1.15": "The Beloved Praises the Shulamite's Beauty",
    "22.2.1": "The Shulamite Praises the Beloved's Appearance",
    "22.2.4": "The Beloved Offers Comfort and Security",
    "22.2.7": "The Shulamite Requests to be Uninterrupted in Love",
    "22.2.8": "The Shulamite Dreams of the Beloved's Arrival",
    "22.2.14": "The Shulamite Senses the Beloved's Presence",
    "22.2.16": "The Shulamite Reflects on Their Mutual Love",
    "22.3.1": "The Shulamite's Dream of Searching for Her Beloved",
    "22.3.5": "The Shulamite's Request for Respect of Their Love",
    "22.3.6": "Solomon's Procession for His Bride",
    "22.4.1": "The Beloved Praises the Shulamite's Beauty",
    "22.4.8": "The Invitation to Consummate Their Love",
    "22.4.16": "The Shulamite's Invitation and Consummation",
    "22.5.2": "The Shulamite's Dream of Delay and Loss",
    "22.5.9": "The Shulamite Praises the Beloved's Attributes",
    "22.6.1": "The Shulamite's Search and Reassurance of Love",
    "22.6.4": "The Beloved Praises the Shulamite's Beauty",
    "22.6.11": "The Shulamite Recalls Their Shared Memories",
    "22.7.1": "The Dance of Mahanaim and Beauty of the Shulamite",
    "22.7.11": "The Shulamite's Invitation to Join Her",
    "22.8.1": "The Shulamite's Reflection on Their Love",
    "22.8.5": "The Beginning and Development of Love",
    "22.8.8": "The Shulamite's Brothers and Their Concern",
    "22.8.11": "Solomon's Vineyard and the Shulamite's Gift",
    "22.8.13": "The Final Exchange between the Lovers",
    "23.1.1": "The Vision of Isaiah",
    "23.1.2": "Judah Confronted for Their Sins",
    "23.1.21": "The Fate of Jerusalem and Future Redemption",
    "23.2.1": "The Lord's Ultimate Reign",
    "23.2.5": "Judgment on the Proud and the Day of the Lord",
    "23.3.1": "Judgment on Jerusalem and Judah",
    "23.3.16": "Sorrow and Hope for Jerusalem",
    "23.4.2": "The Glorious Future of the Remnant",
    "23.5.1": "The Parable of the Vineyard",
    "23.5.8": "Judgment to Follow Sinful Acts",
    "23.6.1": "Isaiah's Vision and Calling",
    "23.6.9": "Message of Judgment and the Holy Seed",
    "23.7.1": "The Sign of Immanuel and Alliance with Assyria",
    "23.8.1": "The Future Invasion and Davidic Kingship",
    "23.8.11": "Warning against Assyrian Alliances",
    "23.9.1": "The Birth and Reign of the Prince of Peace",
    "23.9.8": "Judgment on Israel and Assyria",
    "23.10.5": "Assyria's Downfall and the Remnant of Israel",
    "23.11.1": "The Restoration of Israel and Jesse's Shoot",
    "23.12.1": "Thanksgiving for the Lord's Mercies",
    "23.13.1": "Babylon's Destruction and a Future Restoration",
    "23.14.28": "Judgment on Philistia",
    "23.15.1": "Judgment on Moab",
    "23.17.1": "Judgment and Restoration for Damascus",
    "23.18.1": "The Future Destruction of Cush and Egypt",
    "23.19.1": "Oracle Against Egypt",
    "23.20.1": "Prophecy against Egypt and Cush",
    "23.21.1": "Judgment on Tyre and the Land",
    "23.21.13": "Oracles against Edom and Arabia",
    "23.22.15": "Jerusalem's Corrupt Leadership and the Coming of the Righteous Leader",
    "23.23.1": "Divine Judgment on Tyre",
    "23.24.1": "Destruction of the Earth and Triumph of God",
    "23.25.1": "Judah's Song of Praise and the Judgment of the Nations",
    "23.26.1": "The Feast of Restoration",
    "23.27.1": "Israel's Restoration and Destruction of Enemies",
    "23.28.1": "Woes for Ephraim and Judah",
    "23.29.1": "Woes for Jerusalem and the Assyrians",
    "23.30.1": "Woe to the Stubborn Children",
    "23.31.1": "Egypt's Futile Help and God's Gracious Promise",
    "23.33.1": "Assyria's Fall and the Remnant's Joy",
    "23.34.1": "The Hell of Nations and Security for Zion",
    "23.36.1": "Sennacherib's Invasion",
    "23.38.1": "Hezekiah's Sickness and Recovery",
    "23.39.1": "Hezekiah's Foolish Decision and Babylon's Future",
    "23.40.1": "The Lord's Comfort and Israel's Redemption",
    "23.41.1": "The Servant of the Lord, Israel's Hope",
    "23.43.1": "Songs of the Suffering Servant",
    "23.45.1": "Cyrus the Lord's Shepherd and Jerusalem's Restoration",
    "23.46.1": "Babylon's Downfall",
    "23.48.1": "Israel's Sin and Redemption",
    "23.49.1": "Salvation through the Suffering Servant",
    "23.54.1": "The Glorious Future of Israel and God's Judgment on Nations",
    "23.56.1": "Righteousness and Inclusivity in Worship",
    "23.56.9": "Warnings for the Wicked and Destitute",
    "23.57.14": "The Healing of Repentant Israel",
    "23.58.1": "A Call to True Fasting and Sabbath Observance",
    "23.59.1": "Confession and Hope for Future Blessing",
    "23.60.1": "The Glory of Jerusalem and Redemption for the Peoples",
    "23.61.1": "The Anointed Deliverer and the Liberation of Zion",
    "23.62.1": "Jerusalem's New Name and Future Prosperity",
    "23.63.1": "Judgment on Edom and the Redeemed of Zion",
    "23.63.7": "The Prayer of the Remnant",
    "23.65.1": "The Lord's Answer: A New Heavens and New Earth",
    "23.66.1": "The Final State of Judgment and Blessing",
    "24.1.1": "Introduction and background of Jeremiah",
    "24.1.4": "Jeremiah's calling and preparation",
    "24.1.11": "Visions and encouragement",
    "24.2.1": "Israel's unfaithfulness",
    "24.3.1": "Call for repentance",
    "24.3.6": "Judah's lack of repentance",
    "24.4.1": "Judgment through drought",
    "24.4.29": "Spiritual ignorance of Judah",
    "24.5.1": "Impending invasion",
    "24.5.18": "Call for true justice",
    "24.6.1": "Destruction of Jerusalem foretold",
    "24.7.1": "Temple sermon",
    "24.7.16": "The results of idolatry",
    "24.8.1": "The broken covenant",
    "24.9.1": "Uncontrollable grief",
    "24.10.1": "Circumcision of the heart and judgment",
    "24.11.1": "Terrors from the north",
    "24.11.18": "Jeremiah's personal anguish",
    "24.13.1": "Sign of the linen belt",
    "24.14.1": "Famine and drought",
    "24.15.10": "Jeremiah's complaint and reassurance",
    "24.16.1": "Purity and repentance",
    "24.18.1": "The Potter's House vision",
    "24.19.1": "Reproach and persecution",
    "24.21.1": "Message to King Zedekiah",
    "24.22.1": "Three kings contrasted",
    "24.23.1": "The righteous branch",
    "24.23.9": "Condemnation of false prophets",
    "24.24.1": "The burdens of the nations",
    "24.25.1": "Judah as a wine cup of wrath",
    "24.26.1": "Personal persecution and the yoke",
    "24.28.1": "Parable of the figs",
    "24.29.1": "Jeremiah's letter to exiles",
    "24.30.1": "The Book of Consolation",
    "24.32.1": "Jeremiah's imprisonment and the purchase of land",
    "24.33.1": "The New Covenant",
    "24.34.1": "The warning to Zedekiah and the release of slaves",
    "24.35.1": "The Rekabites as a sign",
    "24.36.1": "Baruch the scribe",
    "24.37.1": "Jeremiah's message to Zedekiah",
    "24.38.1": "The fall of Jerusalem",
    "24.40.1": "Gedaliah's rule and assassination",
    "24.42.1": "Approaching Egypt for protection",
    "24.44.1": "The prophecy against Egypt",
    "24.45.1": "The last words to Baruch",
    "24.46.1": "Against Egypt",
    "24.47.1": "Against Philistia",
    "24.48.1": "Against Moab",
    "24.49.1": "Against Ammon",
    "24.49.7": "Against Edom",
    "24.49.23": "Against Damascus",
    "24.49.28": "Against Kedar and Hazor",
    "24.49.34": "Against Elam",
    "24.50.1": "Against Babylon",
    "24.52.1": "The fall of Jerusalem revisited",
    "25.1.1": "The Loneliness of Jerusalem",
    "25.1.7": "The Sorrow of Jerusalem",
    "25.1.12": "The Suffering of Jerusalem",
    "25.1.17": "The Plea for Compassion",
    "25.2.1": "The Destruction of Jerusalem",
    "25.2.10": "The Mourning of the People",
    "25.2.15": "The Mockery of the Enemies",
    "25.2.18": "The Prayer for Deliverance",
    "25.3.1": "The Distress of the Prophet",
    "25.3.19": "The Hope in God's Faithfulness",
    "25.3.28": "The Submission to God's Discipline",
    "25.3.34": "The Call for Repentance",
    "25.3.43": "The Suffering of the People",
    "25.3.52": "The Prayer for Vengeance",
    "25.4.1": "The Horrors of the Siege",
    "25.4.11": "The Wrath of God",
    "25.4.17": "The Failure of Human Help",
    "25.4.21": "The Punishment of the Enemy",
    "25.5.1": "The Suffering and Humiliation",
    "25.5.11": "The Desolation and Shame",
    "25.5.19": "The Appeal for God's Mercy",
    "26.1.1": "Ezekiel's Vision of the Divine Glory",
    "26.2.1": "Ezekiel's Call and Mission",
    "26.3.1": "Ezekiel Eats the Scroll",
    "26.3.4": "The Prophet's Responsibiliy",
    "26.3.22": "The Prophet's Captivity",
    "26.4.1": "The Siege of Jerusalem",
    "26.4.4": "Ezekiel Lies on His Side",
    "26.4.9": "Rationing Food and Water",
    "26.5.1": "Rending of the Hair",
    "26.5.5": "Woe to Jerusalem",
    "26.6.1": "Prophecy against the Mountains",
    "26.7.1": "The End has Come",
    "26.8.1": "Idolatrous Worship",
    "26.9.1": "Judgment of the Wicked",
    "26.10.1": "Coals of Fire",
    "26.11.1": "God's Presence Leaves Jerusalem",
    "26.12.1": "Judah's Idolatry Denounced",
    "26.13.1": "False Prophets Condemned",
    "26.14.1": "Condemnation of Social Injustice",
    "26.15.1": "Parable of the Vine",
    "26.17.1": "Allegory of the Two Eagles and a Vine",
    "26.18.1": "Individual Responsibility",
    "26.19.1": "Lament for the Princes of Israel",
    "26.20.1": "Allegory of the Shepherds",
    "26.21.1": "Parable of the Forest Fire",
    "26.22.1": "Jerusalem's Sins Depicted",
    "26.23.1": "Parable of the Daughters",
    "26.24.1": "Allegory of the Cooking Pot",
    "26.24.15": "The Death of Ezekiel's Wife",
    "26.25.1": "Judgment on Ammon",
    "26.25.8": "Judgment on Moab",
    "26.25.12": "Judgment on Edom",
    "26.25.15": "Judgment on Philistia",
    "26.26.1": "Oracle against Tyre",
    "26.26.15": "Lament for Tyre",
    "26.28.1": "Oracle against the King of Tyre",
    "26.28.11": "Lament for the King of Tyre",
    "26.28.20": "Judgment on Sidon",
    "26.28.25": "Promised Restoration of Israel",
    "26.29.1": "Prophecy Against Pharaoh",
    "26.29.17": "Nebuchadnezzar's Reward",
    "26.30.1": "Egypt's Desolation",
    "26.30.20": "Lament for Egypt",
    "26.31.1": "The Broken Arms of Pharaoh",
    "26.32.1": "Pharaoh and Egypt's Downfall",
    "26.33.1": "The Watchman Reappointed",
    "26.34.1": "Shepherds and the Sheep",
    "26.35.1": "Against Edom Again",
    "26.36.1": "Vision of New Covenant",
    "26.37.1": "Valley of Dry Bones",
    "26.37.15": "Reunification of Israel",
    "26.38.1": "War of Gog and Magog",
    "26.40.1": "Ezekiel's Temple Tour",
    "26.40.48": "The Details of the Temple",
    "26.42.1": "The Holy Chambers",
    "26.43.1": "The Return of God's Glory",
    "26.43.13": "The Altar and its Rules",
    "26.44.1": "The Allocation of Land to Priests",
    "26.45.1": "The Rules for Prince and People",
    "26.46.1": "Administration of the Temple",
    "26.47.1": "The River of Life",
    "26.47.13": "Division of the Land among the Tribes",
    "26.48.30": "The City of the Lord",
    "27.1.1": "Daniel's commitment to God",
    "27.1.6": "Resolving the dietary test",
    "27.1.17": "God's blessings and favor for Daniel and his friends",
    "27.2.1": "Nebuchadnezzar's troubling dream",
    "27.2.14": "Daniel's prayer for wisdom and its answer",
    "27.2.24": "Revealing the dream",
    "27.2.36": "Interpreting the dream",
    "27.2.46": "Daniel's promotion and his friends' advancement",
    "27.3.1": "The golden image and the king's demand",
    "27.3.8": "The accusation against Shadrach, Meshach, and Abednego",
    "27.3.13": "Their unwavering faith",
    "27.3.19": "The fiery furnace and God's intervention",
    "27.3.28": "Nebuchadnezzar's proclamation and the promotion of Daniel's friends",
    "27.4.1": "Nebuchadnezzar's troubling dream",
    "27.4.10": "Daniel's interpretation of the dream",
    "27.4.28": "The fulfillment of the dream and Nebuchadnezzar's restoration",
    "27.5.1": "The sacrilegious feast",
    "27.5.5": "The mysterious handwriting on the wall",
    "27.5.10": "Daniel interprets the handwriting",
    "27.5.29": "Belshazzar's death and Darius' reign",
    "27.6.1": "Daniel's promotion and the envy of the other administrators",
    "27.6.10": "Daniel's unwavering faith and subsequent persecution",
    "27.6.16": "God's protection in the lion's den",
    "27.6.24": "The vindication of Daniel and punishment of the accusers",
    "27.6.25": "King Darius' proclamation",
    "27.7.1": "Daniel's vision of the four beasts",
    "27.7.9": "The vision of the Ancient of Days and the heavenly court",
    "27.7.15": "The interpretation of the vision",
    "27.8.1": "Daniel's vision of the ram and goat",
    "27.8.15": "The interpretation of the vision by the angel Gabriel",
    "27.9.1": "Daniel's prayer for Jerusalem",
    "27.9.20": "The revelation of the seventy weeks by the angel Gabriel",
    "27.10.1": "The appearance of a heavenly being",
    "27.10.10": "The message to Daniel and the revelation of the kings",
    "27.11.36": "The revelation of the end times and time prophecy",
    "28.1.1": "The word of the Lord to Hosea",
    "28.1.2": "Marriage to Gomer",
    "28.1.4": "Birth of Jezreel",
    "28.1.6": "Birth of Lo-Ruhamah",
    "28.1.8": "Birth of Lo-Ammi",
    "28.1.10": "Prophecy of Israel's Restoration",
    "28.2.1": "Israel's Future Redemption",
    "28.2.2": "The Accusation of Unfaithfulness",
    "28.2.6": "The Punishment of Israel",
    "28.2.14": "Israel's Restoration and Reconciliation",
    "28.3.1": "God's command to love Gomer again",
    "28.3.2": "Hosea's Redemption of Gomer",
    "28.3.4": "Period of Trial and return to God",
    "28.4.1": "The Indictment of Israel",
    "28.4.4": "The Sins of the People and the Priests",
    "28.4.10": "Punishment for immorality and idolatry",
    "28.4.15": "Warning to Judah",
    "28.5.1": "Consequences for the Priests and Royal Family",
    "28.5.8": "Judgment on Israel",
    "28.5.13": "Israel's futile attempts for help",
    "28.6.1": "Invitation to Return to God",
    "28.6.3": "The Promise of God's Restoration",
    "28.6.4": "God's Disappointment with Transient Love",
    "28.6.7": "Covenant Transgressions",
    "28.7.1": "Israel's Scheming and Rebelliousness",
    "28.7.8": "Israel's Corrupt Alliances with Other Nations",
    "28.8.1": "The Sins of Israel",
    "28.8.7": "Reaping the Consequences",
    "28.9.1": "Consequences of Unfaithfulness",
    "28.9.11": "Punishment and Exile",
    "28.10.1": "Israel's Empty Faith",
    "28.10.5": "The Call to Repentance",
    "28.10.9": "The Depravity of Israel",
    "28.10.11": "The Need for Spiritual Reformation",
    "28.11.1": "God's Love for Israel in their Early History",
    "28.11.5": "The Consequences of Disobedience",
    "28.11.8": "God's Torn Compassion",
    "28.11.10": "Promise of Israel's Return",
    "28.12.1": "Indictment against Israel and Judah",
    "28.12.7": "God's Charges Against Israel",
    "28.13.1": "Judgments Against Israel and Judah",
    "28.14.1": "God's Call for Repentance",
    "28.14.4": "God's Promise of Forgiveness and Restoration",
    "28.14.9": "The Wise Response to Hosea's Prophecies",
    "29.1.1": "The word of the Lord that came to Joel",
    "29.1.2": "The devastating locust invasion",
    "29.1.5": "Call for the nation's mourning",
    "29.1.13": "Consecration and prayer by the priests",
    "29.1.15": "Description of the Day of the Lord",
    "29.1.16": "The desolation of the land",
    "29.1.19": "Joel's lament and plea for mercy",
    "29.2.1": "The alarm and warning",
    "29.2.3": "The unstoppable locust army",
    "29.2.10": "The presence of the Lord in judgment",
    "29.2.12": "A call to return to God",
    "29.2.15": "The gathering for prayer and fasting",
    "29.2.18": "The promise of restored blessings",
    "29.2.23": "The promise of abundant harvests",
    "29.2.28": "The promise of the Spirit",
    "29.2.32": "Divine deliverance for the faithful",
    "29.3.1": "The gathering of the nations",
    "29.3.4": "God's charges against the nations",
    "29.3.7": "The retribution upon the nations",
    "29.3.9": "The call to war",
    "29.3.12": "The Day of the Lord and judgment",
    "29.3.15": "The Lord's intervention",
    "29.3.17": "God's dwelling in Zion",
    "29.3.18": "The prosperity and security of God's people",
    "29.3.19": "Judgement on Israel's enemies",
    "29.3.20": "The everlasting habitation in Jerusalem",
    "30.1.1": "Introduction and Call of Amos",
    "30.1.3": "Oracle Against Damascus",
    "30.1.6": "Oracle Against Gaza",
    "30.1.9": "Oracle Against Tyre",
    "30.1.11": "Oracle Against Edom",
    "30.1.13": "Oracle Against Ammon",
    "30.2.1": "Oracle Against Moab",
    "30.2.4": "Oracle Against Judah",
    "30.2.6": "Oracle Against Israel",
    "30.3.1": "Israel's Special Relationship and Punishment",
    "30.3.3": "Rhetorical Questions and Consequences",
    "30.3.9": "Announcement of Judgment",
    "30.4.1": "Indictment of the Wealthy Women",
    "30.4.4": "Sarcasm and Past Warnings",
    "30.4.12": "Call to Repentance",
    "30.5.1": "Lament for Israel",
    "30.5.4": "Exhortation to Seek and Reject Evil",
    "30.5.8": "The Lord, the Creator God",
    "30.5.10": "Consequences of Injustice",
    "30.5.14": "A Call for Repentance",
    "30.5.16": "Day of the Lord as Judgment",
    "30.5.18": "Warning Against Desire for the Day of the Lord",
    "30.5.21": "Rejection of False Worship",
    "30.5.25": "Divine Reminder of Past Judgments",
    "30.6.1": "Woe to the Complacent",
    "30.6.8": "Announcement of Judgment",
    "30.7.1": "First Vision: Locusts",
    "30.7.4": "Second Vision: Fire",
    "30.7.7": "Third Vision: Plumb Line",
    "30.7.10": "Amos' Defense of His Ministry",
    "30.8.1": "Judgment Symbolized",
    "30.8.4": "Woe to the Oppressors",
    "30.8.11": "Famine of God's Word",
    "30.9.1": "Fifth Vision: The Lord by the Altar",
    "30.9.11": "Rebuilding David's Fallen Tent",
    "30.9.13": "Fertility and Abundance in the Land",
    "31.1.1": "Introduction",
    "31.1.2": "Humiliation of Edom",
    "31.1.5": "Destruction of Edom",
    "31.1.8": "Wisdom of Edom",
    "31.1.10": "The Violence Against Jacob",
    "31.1.11": "Edom's Indifference to and Betrayal of Jerusalem",
    "31.1.15": "Judgment Upon the Nations",
    "31.1.17": "Restoration of Israel",
    "31.1.19": "Israel's Expansion",
    "31.1.21": "The Lord's Rule",
    "32.1.1": "The Lord's Command to Jonah",
    "32.1.3": "Jonah Flees from the Lord",
    "32.1.4": "The Great Storm at Sea",
    "32.1.5": "The sailors' initial response",
    "32.1.6": "The captain wakes up Jonah",
    "32.1.7": "Casting lots",
    "32.1.8": "Jonah's confession",
    "32.1.10": "The sailors' fear",
    "32.1.11": "The sailors' request for guidance",
    "32.1.13": "The unsuccessful attempt to return to land",
    "32.1.15": "The sailors throw Jonah overboard",
    "32.1.16": "The Lord relents, and the sailors' reaction",
    "32.2.1": "Jonah's Prayer for Deliverance",
    "32.2.2": "Jonah's anguish and the Lord's response",
    "32.2.3": "Describing his situation",
    "32.2.5": "Near-death experience",
    "32.2.7": "Remembrance of God's temple",
    "32.2.8": "Renouncing idolatry and praising God",
    "32.2.10": "Jonah's Deliverance",
    "32.3.1": "The Lord's Renewed Command to Jonah",
    "32.3.3": "Jonah's Obedience and Preaching in Nineveh",
    "32.3.5": "The people believe and repent",
    "32.3.6": "The proclamation of the king",
    "32.3.10": "God Relents from Destruction",
    "32.4.1": "Jonah's Anger and Complaint",
    "32.4.4": "The Lord's Question to Jonah",
    "32.4.5": "Jonah's shelter and the Lord's provision",
    "32.4.7": "The Lord takes away the plant",
    "32.4.9": "Jonah's misplaced compassion",
    "32.4.10": "God's care for Nineveh",
    "33.1.1": "Introduction",
    "33.1.2": "The Lord as a witness",
    "33.1.5": "Sin and its consequences",
    "33.1.8": "Mourning for Judgment",
    "33.1.10": "The cities of Judah",
    "33.1.16": "Shaving and exile",
    "33.2.1": "Oppression and deceit",
    "33.2.4": "Lamentation of the people",
    "33.2.6": "False prophets",
    "33.2.12": "Gathering the flock",
    "33.2.13": "The King leads the people",
    "33.3.1": "Injustice and oppression",
    "33.3.4": "The Lord's response",
    "33.3.5": "Their deception",
    "33.3.8": "The true prophet",
    "33.3.9": "The wickedness of leaders",
    "33.3.11": "False trust and prophecy",
    "33.3.12": "The coming destruction",
    "33.4.1": "The elevated temple",
    "33.4.2": "Nations seeking the Lord",
    "33.4.3": "Peace and security",
    "33.4.6": "The weak are gathered",
    "33.4.8": "The kingdom restored",
    "33.4.9": "Exile and pain",
    "33.4.11": "The nations gather against Jerusalem",
    "33.5.1": "The ruler struck",
    "33.5.2": "The birthplace",
    "33.5.3": "The deliverance",
    "33.5.4": "The reign of peace",
    "33.5.5": "Protection against Assyria",
    "33.5.7": "The remnant's power",
    "33.5.10": "Destruction of idolatry and enemies",
    "33.6.1": "The Lord's charge",
    "33.6.3": "The Lord's faithfulness",
    "33.6.6": "Offering or obedience",
    "33.6.8": "True requirements",
    "33.6.9": "The Lord's voice",
    "33.6.10": "The sins of the city",
    "33.6.13": "The consequences",
    "33.7.1": "The moral corruption",
    "33.7.3": "Judgments on the wicked",
    "33.7.5": "Trust no one",
    "33.7.7": "Faithful waiting",
    "33.7.8": "Defense and redemption",
    "33.7.11": "Rebuilding and expanding",
    "33.7.14": "Shepherd and flock",
    "33.7.16": "The Lord's power and compassion",
    "33.7.18": "Forgiving and restoring",
    "34.1.1": "The Introduction",
    "34.1.2": "The Character of God",
    "34.1.3": "The Power of God",
    "34.1.7": "The Refuge of God",
    "34.1.9": "The Inevitability of Judgment",
    "34.1.12": "The Restoration of Judah",
    "34.1.14": "The Proclaiming of Judgment",
    "34.1.15": "The Preparations of Invasion",
    "34.2.1": "The Description of Nineveh's Attackers",
    "34.2.3": "The Details of Battle",
    "34.2.6": "The Fall of Nineveh",
    "34.2.11": "The Denunciation of Nineveh's Evil",
    "34.3.1": "Woe to the Bloody City",
    "34.3.5": "The Unveiling of Nineveh's Shame",
    "34.3.8": "The Incorrigible City: Nineveh as Thebes",
    "34.3.12": "The Ineffectual Defenses",
    "34.3.16": "The Inevitable Desolation",
    "34.3.18": "The Irreparable Ruin of Nineveh",
    "35.1.1": "Title: The oracle that Habakkuk the prophet received",
    "35.1.2": "Lament over rampant wickedness",
    "35.1.4": "Cry for justice",
    "35.1.5": "God's surprising plan",
    "35.1.6": "Description of the Babylonians",
    "35.1.10": "Babylonians' arrogance and idolatry",
    "35.1.12": "Questioning God's righteousness",
    "35.1.14": "Puzzlement over God's chosen instrument",
    "35.2.1": "Waiting for God's response",
    "35.2.2": "The vision revealed",
    "35.2.6": "Woe 1: Plunderers being plundered",
    "35.2.9": "Woe 2: Houses built on bloodshed",
    "35.2.12": "Woe 3: Cities built on injustice",
    "35.2.15": "Woe 4: Drunkards and shame",
    "35.2.18": "Woe 5: Worshiping false gods",
    "35.3.1": "Request for mercy",
    "35.3.3": "God's past acts of deliverance",
    "35.3.8": "The power of God over nature",
    "35.3.11": "The Lord as the divine warrior",
    "35.3.16": "Anticipation of future deliverance",
    "36.1.1": "Introduction",
    "36.1.2": "Universal Judgment Announced",
    "36.1.4": "Judah and Jerusalem's Judgment",
    "36.1.7": "The Day of Silence and Sacrifice",
    "36.1.10": "The Day of Lamentation",
    "36.1.12": "The Lord's search and judgment",
    "36.1.13": "A desolate land",
    "36.1.14": "The imminence of judgment",
    "36.1.15": "The severity of judgment",
    "36.1.16": "The nature of the Day of the Lord",
    "36.1.18": "The inability to avoid judgment",
    "36.2.1": "A Call to Repentance",
    "36.2.4": "The destruction of Philistia",
    "36.2.5": "The restoration of the remnant",
    "36.2.8": "The judgment on Moab and Ammon",
    "36.2.10": "The Lord's global recognition",
    "36.2.12": "Judgment against Ethiopia",
    "36.2.13": "The destruction of Assyria",
    "36.2.14": "The desolation of Nineveh",
    "36.3.1": "The Wickedness of Jerusalem",
    "36.3.8": "The Gathering and Judgment",
    "36.3.9": "The restored communication",
    "36.3.10": "The humbled and devoted remnant",
    "36.3.13": "The righteous and faithful people",
    "36.3.14": "Joyful singing",
    "36.3.15": "The abiding presence of the Lord",
    "36.3.16": "Fearlessness and strength",
    "36.3.17": "The Lord's delight and love",
    "36.3.18": "The lifting of sorrow",
    "36.3.19": "The gathering of the dispersed",
    "36.3.20": "The exaltation of Israel",
    "37.1.1": "Prophetic Call of Haggai",
    "37.1.2": "The time is not right",
    "37.1.3": "The people's comfort prioritized",
    "37.1.5": "Call to reflection",
    "37.1.7": "God's response to their neglect",
    "37.1.12": "Obedience of Zerubbabel and Joshua",
    "37.1.13": "The people's motivation",
    "37.1.14": "The start of the rebuilding",
    "37.2.1": "Prophetic date and context",
    "37.2.3": "Questioning the temple's glory",
    "37.2.4": "Encouragement to be strong",
    "37.2.5": "Reminder of God's covenant",
    "37.2.6": "A great shaking",
    "37.2.7": "The wealth of nations",
    "37.2.9": "Greater glory and peace",
    "37.2.10": "Inquiry about ritual purity",
    "37.2.12": "The priests' answers",
    "37.2.15": "Past consequences",
    "37.2.18": "Commitment to obedience",
    "37.2.20": "The Day of Overthrow and Judgment",
    "37.2.21": "The coming shake up",
    "37.2.23": "Zerubbabel as God's chosen servant",
    "38.1.1": "Title and Date",
    "38.1.2": "Call to Repentance",
    "38.1.7": "The Horses Patrolling",
    "38.1.12": "Intercession for Jerusalem",
    "38.1.18": "The Four Horns",
    "38.1.20": "The Four Craftsmen",
    "38.2.1": "The Man's Task",
    "38.2.3": "Intercession for Israel",
    "38.2.6": "A Call to Return and Rejoice",
    "38.3.1": "Accusation and Cleansing",
    "38.3.6": "The Charge and Prophecy",
    "38.4.1": "The Lampstand and Olive Trees",
    "38.4.4": "The Meaning of the Vision",
    "38.5.1": "The Scroll's Description",
    "38.5.3": "The Scroll's Purpose",
    "38.5.5": "The Woman and the Basket",
    "38.5.9": "The Removal of Wickedness",
    "38.6.1": "The Chariots' Description",
    "38.6.4": "The Chariots' Mission",
    "38.6.9": "The Crowning of Joshua",
    "38.6.12": "The Prophecy of the Branch",
    "38.6.14": "The Promise of God's Presence",
    "38.7.1": "Inquiry about Fasting",
    "38.7.4": "God's Response to Superficial Rituals",
    "38.7.8": "Call to Obedience",
    "38.8.1": "Promise of Blessing and Restoration",
    "38.8.18": "Transformation of Fasting to Joy",
    "38.9.1": "Judgment on Israel's Enemies",
    "38.9.9": "The Coming of the King",
    "38.9.11": "The Covenant and Victory",
    "38.10.1": "Blessing upon the Land",
    "38.11.1": "The Rejection of the Shepherd",
    "38.12.1": "Jerusalem: A Cup of Reeling",
    "38.12.10": "Mourning for the Pierced One",
    "38.13.1": "A Fountain of Cleansing",
    "38.13.7": "The Smitten Shepherd and the Scattered Flock",
    "38.14.1": "The Day of the Lord",
    "39.1.1": "Prologue: The word of the Lord to Malachi",
    "39.1.2": "God's love demonstrated",
    "39.1.4": "Edom's destruction",
    "39.1.6": "Priests' disrespect towards God",
    "39.1.10": "The worthlessness of their offerings",
    "39.2.1": "The cursed blessings",
    "39.2.4": "The broken covenant",
    "39.2.10": "The betrayal of brothers",
    "39.2.11": "The alliance with foreign women",
    "39.2.14": "The danger of divorce",
    "39.2.17": "The challenge to God's justice",
    "39.3.1": "The announcement of the messenger",
    "39.3.2": "The refiner's fire",
    "39.3.5": "The day of judgment",
    "39.3.6": "Israel's unfaithfulness",
    "39.3.8": "Robbing God through tithes and offerings",
    "39.3.10": "The test of faithfulness and God's blessing",
    "39.3.13": "The words against God",
    "39.3.16": "The faithful remnant and the book of remembrance",
    "39.4.1": "The burning day",
    "39.4.2": "The healing sun",
    "39.4.4": "The call to remember the Law of Moses",
    "39.4.5": "The announcement of Elijah's coming",
    "39.4.6": "The reconciliation of families",
    "40.1.1": "Genealogy of Jesus",
    "40.1.18": "Virgin Birth of Jesus",
    "40.2.1": "Wise Men from the East",
    "40.2.13": "Flight to Egypt",
    "40.2.16": "Herod's Massacre of the Infants",
    "40.2.19": "Return to Nazareth",
    "40.3.1": "The Proclamation of John the Baptist",
    "40.3.13": "Jesus' Baptism",
    "40.4.1": "Temptation of Jesus",
    "40.4.12": "Beginning of Jesus' Ministry in Galilee ",
    "40.4.18": "Calling of the First Disciples",
    "40.4.23": "Jesus' Miracles and Healing Ministry",
    "40.5.1": "The Beatitudes",
    "40.5.13": "Salt and Light",
    "40.5.17": "Jesus and the Law",
    "40.5.21": "Righteousness Exemplified",
    "40.6.1": "Motives in Giving, Praying, and Fasting",
    "40.6.19": "Treasures in Heaven",
    "40.6.25": "Do Not Worry",
    "40.7.1": "Do Not Judge",
    "40.7.7": "Ask, Seek, and Knock",
    "40.7.13": "The Narrow Gate",
    "40.7.15": "Fruit and False Prophets",
    "40.7.21": "True Discipleship",
    "40.7.24": "The Wise and Foolish Builders",
    "40.8.1": "Jesus Heals a Leper",
    "40.8.5": "Jesus and the Centurion's Servant",
    "40.8.14": "Jesus Heals Peter's Mother-in-law",
    "40.8.23": "Calming the Storm",
    "40.8.28": "Healing of Demon-Possessed Men",
    "40.9.1": "Jesus Forgives and Heals a Paralytic",
    "40.9.9": "Calling of Matthew",
    "40.9.14": "Jesus Questioned About Fasting",
    "40.9.18": "Healing of a Sick Woman and a Dead Girl",
    "40.9.27": "Healing of Two Blind Men and a Mute Man",
    "40.9.35": "Compassion for the Lost",
    "40.10.1": "Sending Out the Twelve",
    "40.11.1": "Jesus' teaching about John the Baptist",
    "40.11.2": "John the Baptist's Question",
    "40.11.7": "Jesus' Praise for John",
    "40.11.20": "Judgment Announced",
    "40.11.25": "Rest for the Weary",
    "40.12.1": "Jesus and the Sabbath",
    "40.12.15": "Jesus, God's Chosen Servant",
    "40.12.22": "Jesus and Beelzebul",
    "40.12.38": "Demand for a Sign",
    "40.12.46": "Jesus' True Family",
    "40.13.1": "The Parable of the Sower",
    "40.13.10": "The Purpose of the Parables",
    "40.13.18": "The Parable of the Sower Explained",
    "40.13.24": "Parables of Weeds, Mustard Seed, and Yeast",
    "40.13.34": "The Parables and Prophecy Fulfilled",
    "40.13.36": "The Weeds Explained",
    "40.13.44": "Parables of Treasure, Pearl, and Net",
    "40.13.53": "Rejection at Nazareth",
    "40.14.1": "John the Baptist's Death",
    "40.14.13": "Jesus Feeds the Five Thousand",
    "40.14.22": "Jesus Walks on Water",
    "40.15.1": "Debates with Pharisees and Teachings on Purity",
    "40.15.21": "Healing a Canaanite Woman's Daughter",
    "40.15.29": "Jesus Heals Many and Feeds the Four Thousand",
    "40.16.1": "The Demand for a Sign",
    "40.16.5": "The Yeast of the Pharisees and Sadducees",
    "40.16.13": "Peter's Declaration of Jesus as the Messiah",
    "40.16.21": "Jesus Predicts His Death and Resurrection",
    "40.17.1": "The Transfiguration",
    "40.17.14": "Healing a Demon-Possessed Boy",
    "40.17.22": "Jesus Predicts His Death and Resurrection Again",
    "40.17.24": "Temple Tax",
    "40.18.1": "Teachings on Humility and Discipline",
    "40.19.1": "Divorce and Remarriage",
    "40.19.13": "Jesus Blesses the Children",
    "40.19.16": "The Rich Young Man",
    "40.20.1": "The Parable of the Workers in the Vineyard",
    "40.20.17": "Jesus Foretells His Death and Resurrection Third Time",
    "40.20.20": "A Mother's Request and Servant Leadership",
    "40.20.29": "Healing of Two Blind Men",
    "40.21.1": "Jesus' Triumphal Entry into Jerusalem",
    "40.21.12": "Jesus Cleanses the Temple",
    "40.21.18": "Cursing the Fig Tree",
    "40.21.23": "Jesus Authority Questioned",
    "40.21.28": "Parables of the Two Sons, Tenants, and Wedding Feast",
    "40.22.15": "Paying Taxes to Caesar",
    "40.22.23": "The Sadducees and the Resurrection",
    "40.22.34": "The Greatest Commandment",
    "40.22.41": "Jesus Questions the Pharisees",
    "40.23.1": "Jesus Condemns the Scribes and Pharisees",
    "40.24.1": "The Widow's Offering",
    "40.24.15": "Destruction of the Temple and Signs of the End Times",
    "40.25.1": "The Parable of the Ten Virgins",
    "40.25.14": "The Parable of the Talents",
    "40.25.31": "The Sheep and the Goats",
    "40.26.1": "Jesus' Anointing at Bethany",
    "40.26.14": "Judas' Betrayal",
    "40.26.17": "The Last Supper",
    "40.26.31": "Gethsemane",
    "40.26.47": "Jesus' Arrest",
    "40.26.57": "Jesus before the Sanhedrin",
    "40.26.69": "Peter's Denial",
    "40.27.1": "Jesus before Pilate",
    "40.27.27": "The Soldiers Mock Jesus",
    "40.27.32": "The Crucifixion",
    "40.27.45": "Jesus' Death, Burial, and Resurrection",
    "40.28.11": "The Report of the Guard",
    "40.28.16": "The Great Commission",
    "41.1.1": "The Proclamation of John the Baptist",
    "41.1.9": "Jesus' Baptism and Spiritual Anointing",
    "41.1.12": "Jesus' Temptation in the Wilderness",
    "41.1.14": "The Call of the First Disciples",
    "41.1.21": "Teaching with Authority",
    "41.1.29": "Healing Peter's Mother-in-law and Others",
    "41.1.35": "Preaching in Other Towns",
    "41.1.40": "Healing a Leper",
    "41.2.1": "Forgiving and Healing a Paralytic",
    "41.2.13": "The Call of Levi and Eating with Sinners",
    "41.2.18": "The Question about Fasting",
    "41.2.23": "Jesus' Interpretation of the Sabbath",
    "41.3.7": "Selecting the Twelve Apostles",
    "41.3.20": "Accusations and Jesus' Response",
    "41.4.1": "The Parable of the Sower",
    "41.4.10": "The Purpose of Parables",
    "41.4.13": "The Parable of the Sower Explained",
    "41.4.21": "Other Parables and Teachings",
    "41.4.35": "Calming the Storm",
    "41.5.1": "The Gerasene Demoniac",
    "41.5.21": "Healing of the Woman with Bleeding and Raising of Jairus' Daughter",
    "41.6.1": "Rejection in Nazareth and Mission of the Twelve",
    "41.6.30": "Feeding the Five Thousand and Walking on Water",
    "41.7.1": "Teachings on Clean and Unclean, and Healing of a Gentile Woman",
    "41.7.31": "Healing the Deaf and Mute Man and Feeding the Four Thousand",
    "41.8.11": "Pharisees Ask for a Sign and Further Teachings",
    "41.8.27": "Peter's Confession and First Passion Prediction",
    "41.9.2": "The Transfiguration and Healing of a Boy with an Evil Spirit",
    "41.9.30": "Second Passion Prediction and Disciples' Misunderstanding",
    "41.10.1": "Teaching on Divorce",
    "41.10.13": "Jesus Blesses the Children",
    "41.10.17": "The Rich Young Ruler",
    "41.10.32": "Third Passion Prediction and the Request of Two Disciples",
    "41.10.46": "Healing of Blind Bartimaeus",
    "41.11.1": "Jesus' Triumphal Entry",
    "41.11.12": "Jesus Curses the Fig Tree and Cleanses the Temple",
    "41.11.20": "Lessons from the Cursed Fig Tree",
    "41.11.27": "The Challenge of Jesus' Authority",
    "41.12.1": "The Parable of the Vineyard",
    "41.12.13": "Paying Taxes to the Romans",
    "41.12.18": "The Question about Resurrection",
    "41.12.28": "The Commandments and the Messianic Psalm",
    "41.13.1": "The Olivet Discourse: Signs of the End Times",
    "41.14.1": "The Plot to Kill Jesus and His Anointing at Bethany",
    "41.14.12": "The Last Supper",
    "41.14.27": "Gethsemane: Jesus' Agony and Arrest",
    "41.14.53": "Jesus' Trial and Peter's Denial",
    "41.15.1": "Jesus before Pilate, Crucifixion, and Death",
    "41.16.1": "The Empty Tomb",
    "41.16.9": "Jesus' Appearances and the Great Commission",
    "42.1.1": "Introduction to Luke",
    "42.1.5": "Gabriel's appearance to Zechariah",
    "42.1.18": "Zechariah's disbelief and punishment",
    "42.1.26": "Gabriel's appearance to Mary",
    "42.1.34": "Mary's acceptance",
    "42.1.39": "Elizabeth's joyful greeting",
    "42.1.46": "Mary's song of praise",
    "42.1.57": "Naming of John",
    "42.1.67": "Zechariah's prophetic song and recovery",
    "42.1.80": "John's early life",
    "42.2.1": "Jesus' birth in Bethlehem",
    "42.2.8": "The angels appear to shepherds",
    "42.2.15": "The shepherds visit Jesus",
    "42.2.21": "Circumcision and naming",
    "42.2.22": "Simeon's prophecy",
    "42.2.36": "Anna's testimony",
    "42.2.39": "Jesus' family returns to Nazareth",
    "42.2.41": "Jesus at the temple",
    "42.2.51": "Jesus' development",
    "42.3.1": "John's preaching",
    "42.3.7": "John's exhortations",
    "42.3.15": "John announces the Messiah",
    "42.3.21": "The baptism of Jesus",
    "42.3.23": "The genealogy of Jesus",
    "42.4.1": "The temptation of Jesus",
    "42.4.14": "Jesus' early ministry in Galilee",
    "42.4.16": "Jesus' rejection at Nazareth",
    "42.4.31": "Jesus casts out demons and heals the sick",
    "42.5.1": "Calling of the first disciples",
    "42.5.12": "Jesus heals a leper and a paralytic",
    "42.5.27": "Calling of Levi and dining with sinners",
    "42.6.1": "Jesus' authority questioned",
    "42.6.12": "Choosing the twelve apostles",
    "42.6.17": "Sermon on the plain",
    "42.7.1": "Jesus heals a centurion's servant",
    "42.7.11": "Jesus raises a widow's son",
    "42.7.18": "Jesus and John the Baptist",
    "42.7.36": "Jesus anointed by a sinful woman",
    "42.8.1": "Jesus' female supporters",
    "42.8.4": "Parable of the sower",
    "42.8.16": "Light under a bowl",
    "42.8.19": "Jesus' true family",
    "42.8.22": "Jesus calms the storm",
    "42.8.26": "The healing of a demon-possessed man",
    "42.8.40": "Healing Jairus' daughter and woman with a bleeding issue",
    "42.9.1": "Sending out the twelve",
    "42.9.7": "Herod's fears about Jesus",
    "42.9.10": "Feeding the five thousand",
    "42.9.18": "Peter's confession and Jesus' prediction of suffering",
    "42.9.28": "Transfiguration of Jesus",
    "42.9.37": "Healing of a demon-possessed boy",
    "42.9.43": "Jesus predicts his death for the second time",
    "42.9.46": "Jesus teaches true greatness",
    "42.9.51": "Rejection in a Samaritan village",
    "42.9.57": "The cost of discipleship",
    "42.10.1": "Sending out the seventy-two",
    "42.10.21": "The joy of Jesus",
    "42.10.25": "The parable of the Good Samaritan",
    "42.10.38": "Jesus visits Mary and Martha",
    "42.11.1": "Jesus teaches on prayer",
    "42.11.14": "Conflicts with the Pharisees and teachers",
    "42.12.1": "Fearless faith in the face of persecution",
    "42.12.13": "The parable of the rich fool",
    "42.12.22": "Teachings on anxiety, greed, and watchfulness",
    "42.12.49": "Jesus speaking about division, repentance, and interpreting the times",
    "42.13.10": "Healing on the Sabbath",
    "42.13.18": "The Kingdom of God and the narrow door",
    "42.13.31": "Jesus laments over Jerusalem",
    "42.14.1": "Healing on the Sabbath and teaching about pride and humility",
    "42.14.25": "The cost of discipleship",
    "42.15.1": "Parables of the lost sheep, lost coin and prodigal son",
    "42.16.1": "The parable of the shrewd manager",
    "42.16.19": "The rich man and Lazarus",
    "42.17.1": "Teachings on sin, faith, and duty",
    "42.17.11": "The healing of ten lepers",
    "42.17.20": "The coming of the Kingdom",
    "42.18.1": "Parables on prayer and humility",
    "42.18.15": "Jesus, children and wealth",
    "42.18.31": "Jesus predicts his death for the third time",
    "42.18.35": "Healing of the blind man",
    "42.19.1": "The salvation of Zacchaeus",
    "42.19.11": "The parable of the ten servants",
    "42.19.28": "The triumphal entry into Jerusalem",
    "42.19.45": "Jesus cleanses the temple",
    "42.20.1": "Authority of Jesus questioned",
    "42.20.9": "Parables about Israel's unbelief",
    "42.20.20": "Questions about loyalty to Rome and resurrection",
    "42.20.41": "Jesus' teaching about the Messiah and religious leaders",
    "42.21.1": "The widow's offering",
    "42.21.5": "The Olivet Discourse",
    "42.22.1": "The plot to betray Jesus and the Last Supper",
    "42.22.39": "Jesus' prayer and betrayal in Gethsemane",
    "42.22.54": "Peter's denial and Jesus' trial before the Jewish authorities",
    "42.23.1": "Jesus' trial before Pilate and Herod",
    "42.23.26": "The crucifixion and death of Jesus",
    "42.23.50": "The burial of Jesus",
    "42.24.1": "The resurrection of Jesus",
    "42.24.13": "The walk to Emmaus",
    "42.24.36": "Jesus appears to the disciples in Jerusalem",
    "42.24.50": "The ascension of Jesus",
    "43.1.1": "The Word and Creation",
    "43.1.6": "John the Baptist's Witness",
    "43.1.9": "The Word and Incarnation",
    "43.1.15": "Testimony of the Word and the Baptist",
    "43.1.19": "The Witness of John the Baptist",
    "43.1.35": "The First Disciples",
    "43.2.1": "The Wedding at Cana",
    "43.2.13": "Jesus Cleanses the Temple",
    "43.3.1": "Nicodemus and the New Birth",
    "43.3.22": "John the Baptist's Testimony about Jesus",
    "43.4.1": "Jesus and the Woman of Samaria",
    "43.4.27": "The Harvest of the Gospel",
    "43.4.43": "Jesus Heals an Official's son",
    "43.5.1": "Healing at the Pool of Bethesda",
    "43.5.19": "The Authority of the Son",
    "43.5.30": "Witnesses to Jesus",
    "43.6.1": "Feeding the Five Thousand",
    "43.6.16": "Jesus Walks on Water",
    "43.6.22": "The Bread of Life Discourse",
    "43.6.60": "Many Disciples Turn Away",
    "43.7.1": "The Feast of Booths",
    "43.7.14": "Jesus Teaches at the Feast",
    "43.7.25": "Division among the People",
    "43.8.1": "The Woman Caught in Adultery",
    "43.8.12": "Jesus, the Light of the World",
    "43.8.21": "The Truth Shall Set You Free",
    "43.8.31": "The Children of Abraham and God",
    "43.9.1": "Healing of the Man Born Blind",
    "43.10.1": "The Good Shepherd",
    "43.10.22": "Jesus at the Feast of Dedication",
    "43.11.1": "The Raising of Lazarus",
    "43.11.45": "The Plot to Kill Jesus",
    "43.12.1": "Mary Anoints Jesus",
    "43.12.12": "The Triumphal Entry",
    "43.12.20": "Jesus Predicts His Death",
    "43.12.37": "The Unbelief of the People",
    "43.13.1": "Jesus Washes the Disciples' Feet",
    "43.13.21": "Jesus Foretells His Betrayal",
    "43.14.1": "Jesus Comforts His Disciples",
    "43.14.15": "The Promise of the Holy Spirit",
    "43.15.1": "The Vine and the Branches",
    "43.15.18": "The World's Hatred for Believers",
    "43.16.5": "The Work of the Holy Spirit",
    "43.16.16": "Jesus' Departure and Return",
    "43.17.1": "Jesus Prays for Himself",
    "43.17.6": "Jesus Prays for His Disciples",
    "43.17.20": "Jesus Prays for All Believers",
    "43.18.1": "Jesus' Arrest",
    "43.18.12": "Jesus before Annas and Caiaphas",
    "43.18.28": "Jesus before Pilate",
    "43.19.17": "The Crucifixion",
    "43.19.28": "The Death and Burial of Jesus",
    "43.20.1": "The Empty Tomb",
    "43.20.11": "Jesus Appears to Mary Magdalene",
    "43.20.19": "Jesus Appears to His Disciples",
    "43.20.24": "Jesus and Thomas",
    "43.20.30": "The Purpose of John's Gospel",
    "43.21.1": "Jesus Appears beside the Sea of Galilee",
    "43.21.15": "Jesus and Peter",
    "43.21.20": "Jesus and the Beloved Disciple",
    "43.21.25": "The Gospel's Conclusion",
    "44.1.1": "The Prologue",
    "44.1.3": "Preparation and Ascension of Jesus",
    "44.1.12": "Waiting for the Holy Spirit",
    "44.1.15": "Selection of Matthias",
    "44.2.1": "Pentecost and the Coming of the Holy Spirit",
    "44.2.14": "Peter's Sermon",
    "44.2.37": "Conviction and Conversion of Three Thousand",
    "44.2.42": "Life and Fellowship of the Early Church",
    "44.3.1": "Healing of the Lame Beggar",
    "44.3.11": "Peter's Second Sermon",
    "44.4.1": "Persecution and Boldness of Peter and John",
    "44.4.23": "Believers' Prayer for Boldness",
    "44.4.32": "Sharing Possessions among Believers",
    "44.5.1": "Ananias and Sapphira",
    "44.5.12": "Signs and Wonders; Growing Persecution",
    "44.6.1": "Appointment of the Seven",
    "44.6.8": "Stephen's Arrest and Defense",
    "44.7.54": "Stephen's Martyrdom",
    "44.8.1": "The Persecution and Dispersal of the Early Church",
    "44.8.4": "Philip and the Samaritans",
    "44.8.26": "Philip and the Ethiopian Eunuch",
    "44.9.1": "Conversion of Saul",
    "44.9.20": "Saul's Early Christian Experience",
    "44.9.32": "Peter's Miracles",
    "44.10.1": "Peter and Cornelius",
    "44.11.1": "Peter's Report to Jerusalem",
    "44.11.19": "Church Growth in Antioch",
    "44.11.27": "Relief Ministry in Judea",
    "44.12.1": "James' Execution and Peter's Escape",
    "44.12.20": "Death of Herod",
    "44.12.24": "Summary of the Expansion",
    "44.13.1": "Sending Off Barnabas and Saul",
    "44.13.4": "Gospel in Cyprus",
    "44.13.13": "Arrival in Pisidian Antioch",
    "44.14.1": "Travels in Iconium, Lystra, and Derbe",
    "44.14.24": "Return and Reporting in Antioch",
    "44.15.1": "Controversy Over Circumcision",
    "44.15.6": "Peter's Testimony",
    "44.15.12": "Barnabas and Paul's Report",
    "44.15.13": "James' Conclusion and Letter",
    "44.15.30": "Returning to Antioch and the Dispute between Paul and Barnabas",
    "44.15.36": "Paul and Silas' Departure",
    "44.16.1": "Derbe, Lystra, and the Call to Macedonia",
    "44.16.11": "Philippi: Lydia and the Jailer",
    "44.17.1": "Thessalonica, Berea, and Athens",
    "44.18.1": "Ministry in Corinth",
    "44.18.18": "Return and Report in Antioch",
    "44.18.23": "Ministry in Galatia and Phrygia",
    "44.18.24": "Apollos in Corinth",
    "44.19.1": "Ephesus: Growth and Opposition",
    "44.20.17": "Farewell to Ephesian Elders",
    "44.21.1": "Back to Jerusalem",
    "44.21.17": "Paul's Arrival and Arrest in Jerusalem",
    "44.21.37": "Paul's Defense before the Crowd",
    "44.22.30": "Paul before the Sanhedrin",
    "44.23.12": "The Plot Against Paul and Transfer to Caesarea",
    "44.24.1": "Paul before Governor Felix",
    "44.25.1": "Paul before Governor Festus",
    "44.25.13": "Paul before King Agrippa",
    "44.27.1": "Paul's Journey to Rome",
    "44.27.13": "The Storm at Sea",
    "44.27.39": "The Shipwreck on Malta",
    "44.28.11": "Arrival in Rome",
    "44.28.17": "Paul's Ministry in Rome",
    "45.1.1": "Greetings and Salutation",
    "45.1.8": "Paul's Longing to Visit Rome",
    "45.1.16": "The Theme of the Gospel: Righteousness from God",
    "45.1.18": "The Ungodliness of the Gentiles",
    "45.1.24": "The Consequences of Gentile Unrighteousness",
    "45.2.1": "God's Righteous Judgment Applies to Everyone",
    "45.2.17": "The Inadequacy of Ritual and Law",
    "45.3.1": "The Jewish Advantage and Their Faithlessness",
    "45.3.9": "Universal Need for Salvation",
    "45.3.21": "Justification by Faith Apart from the Law",
    "45.3.27": "Boasting is Excluded",
    "45.4.1": "Abraham Justified by Faith",
    "45.4.9": "Abraham's Faith Prior to Circumcision",
    "45.4.13": "The Promise through Faith, Not Law",
    "45.4.18": "The Unwavering Faith of Abraham",
    "45.5.1": "The Benefits of Justification",
    "45.5.12": "Justification through Christ and Adam's Contrast",
    "45.6.1": "Dead to Sin, Alive in Christ",
    "45.6.15": "Slavery to Righteousness",
    "45.7.1": "Death to the Law",
    "45.7.7": "The Purpose and Failure of the Law",
    "45.8.1": "The New Way of Life in the Spirit",
    "45.8.12": "Sonship and Heirship",
    "45.8.18": "The Future Hope and Glory",
    "45.8.31": "The Unfailing Love of God",
    "45.9.1": "Israel's Privileges and Rejection",
    "45.9.6": "God's Choice and Election",
    "45.9.14": "God's Mercy and Justice",
    "45.9.30": "Israel's Pursuit of Righteousness by Works",
    "45.10.5": "Faith is the Key to Righteousness",
    "45.10.14": "The Proclamation of Faith",
    "45.11.1": "God Has Not Rejected Israel",
    "45.11.11": "The Inclusion of Gentiles and Future Restoration",
    "45.11.25": "The Mystery of Israel's Restoration",
    "45.11.33": "Praise to God's Wisdom and Knowledge",
    "45.12.1": "Presenting Ourselves to God",
    "45.12.3": "Using Our Gifts for the Body of Christ",
    "45.12.9": "Marks of a True Christian",
    "45.13.1": "Submission to Governing Authorities",
    "45.13.8": "Love Fulfills the Law",
    "45.13.11": "The Urgency of Salvation",
    "45.14.1": "Living to the Lord",
    "45.14.13": "The Law of Love",
    "45.15.1": "Christ the Model of Unity",
    "45.15.14": "Paul's Ministry and Travel Plans",
    "45.16.1": "Personal Greetings and Final Instructions",
    "46.1.1": "Greeting",
    "46.1.4": "Thanksgiving",
    "46.1.10": "Call for Unity",
    "46.1.18": "Wisdom and the Cross",
    "46.2.1": "Spiritual Wisdom versus Human Wisdom",
    "46.3.1": "Spiritual Maturity",
    "46.3.5": "Apostles as God's Workers",
    "46.3.16": "God's Temple",
    "46.4.1": "Faithful Servants",
    "46.4.6": "A Contrast in Values",
    "46.4.14": "Paul's Fatherly Concern",
    "46.5.1": "Expelling the Immoral Brother",
    "46.6.1": "Settling Disputes in the Church",
    "46.6.12": "The Body: Sexual Immorality and Honouring God",
    "46.7.1": "Marriage Duties and the Unmarried",
    "46.7.10": "Marriage, Separation, and Divorce",
    "46.7.17": "Contentment in One's Situation",
    "46.7.25": "The Single Life and Dedication to God",
    "46.7.36": "Marriage, Widows, and Widowers",
    "46.8.1": "Knowledge and Love in Connection to Idols",
    "46.9.1": "Paul's Example of Renouncing his Rights",
    "46.10.1": "Learning from Israel's Failures",
    "46.10.14": "Participating in Idol Feasts",
    "46.10.23": "Seeking the Good of Others",
    "46.11.2": "Head Coverings in Worship",
    "46.11.17": "Correcting the Lord's Supper",
    "46.12.1": "The Purpose and Diversity of Spiritual Gifts",
    "46.12.12": "The Body of Christ and Unity",
    "46.13.1": "The Supremacy of Love",
    "46.14.1": "Prophecy and Tongues",
    "46.14.26": "Orderly Worship",
    "46.15.1": "The Gospel and the Resurrection",
    "46.15.12": "The Importance of the Resurrection",
    "46.15.35": "The Nature of the Resurrection Body",
    "46.15.50": "Victory over Death",
    "46.16.1": "Instructions on the Collection for the Saints",
    "46.16.5": "Paul's Travel Plans",
    "46.16.13": "General Exhortations and Greetings",
    "47.1.1": "Greetings",
    "47.1.3": "Comfort in Suffering",
    "47.1.8": "Paul's Deliverance from Persecution",
    "47.1.12": "Paul's Integrity and Motives",
    "47.1.15": "The Change of Plans Explained",
    "47.1.23": "The Purpose of the Delay",
    "47.2.1": "Reaffirming Forgiveness to the Offender",
    "47.2.12": "Thanksgiving for the Triumph in Ministry",
    "47.3.1": "Letters of Recommendation",
    "47.3.4": "Dependence on God",
    "47.3.7": "The Greater Glory of the New Covenant",
    "47.4.1": "The Ministry of Reconciliation",
    "47.4.7": "Suffering and Renewal",
    "47.5.1": "The Eternal Dwelling and Judgment",
    "47.5.11": "The Love of Christ Compels Us",
    "47.5.16": "The Message of Reconciliation",
    "47.6.1": "Paul's Appeal for their Openness",
    "47.6.14": "Separate from Unbelievers",
    "47.7.2": "The Joy of Reconciliation with the Corinthians",
    "47.8.1": "The Macedonians' Generosity",
    "47.8.6": "The Example of Jesus",
    "47.8.10": "The Corinthians' Participation",
    "47.8.16": "The Delegates for the Collection",
    "47.9.1": "The Willingness to Give",
    "47.9.6": "The Benefits of Generosity",
    "47.10.1": "The Lordship of Christ",
    "47.10.7": "Paul's Authority and Boasting",
    "47.11.1": "Warnings against False Apostles",
    "47.11.16": "Paul's Sufferings and Weakness",
    "47.12.1": "Paul's Vision and Thorn in the Flesh",
    "47.12.11": "Paul's Concern and Final Visit",
    "47.13.1": "Final Warnings and Exhortation",
    "47.13.11": "Concluding Greetings",
    "48.1.1": "Opening Greeting",
    "48.1.3": "Grace and Peace",
    "48.1.6": "The Galatians' Desertion of the True Gospel",
    "48.1.10": "Paul's Calling and Independence",
    "48.1.18": "Paul's Visit to Jerusalem",
    "48.2.1": "Paul's Apostolic Agreement with Peter, James, and John",
    "48.2.11": "Paul's Confrontation with Peter at Antioch",
    "48.2.15": "The Basis of Justification",
    "48.2.17": "The Implications of Justification",
    "48.2.20": "Union with Christ",
    "48.3.1": "The Experience of the Believers",
    "48.3.6": "The Abraham Example",
    "48.3.15": "The Purpose of the Law",
    "48.3.19": "The Mediator of the Law",
    "48.3.21": "The Function of the Law",
    "48.3.26": "The Unity of Believers",
    "48.4.1": "Heirs in Christ",
    "48.4.8": "The Danger of Returning to Slavery",
    "48.4.12": "Paul's Personal Appeal",
    "48.4.21": "The Two Covenants",
    "48.4.29": "Applications for the Believers",
    "48.5.1": "The Danger of Legalism",
    "48.5.7": "The Encouragement to Stand Firm",
    "48.5.13": "The Call to Serve One Another",
    "48.5.16": "Life in the Spirit",
    "48.5.19": "Contrasting the Works of the Flesh and the Fruit of the Spirit",
    "48.5.24": "Walking in the Spirit",
    "48.6.1": "Restoring the Fallen",
    "48.6.3": "Humility and Self-Reflection",
    "48.6.6": "Generosity in Giving",
    "48.6.10": "Doing Good to All People",
    "48.6.11": "Paul's Personal Reminder",
    "48.6.12": "The Motives of the Circumcision Party",
    "48.6.14": "Boasting in the Cross of Christ",
    "48.6.17": "The Peace and Mercy upon True Believers",
    "49.1.1": "Greeting and Introduction",
    "49.1.3": "Praise to God for every spiritual blessing",
    "49.1.4": "Chosen and predestined for holiness",
    "49.1.7": "Redemption through Christ's blood",
    "49.1.11": "Inheritance and sealing with the Holy Spirit",
    "49.1.15": "Thanksgiving for their faith and love",
    "49.1.17": "Prayer for spiritual wisdom and understanding",
    "49.1.20": "God's power at work in Christ",
    "49.2.1": "Describing spiritual death",
    "49.2.4": "God's mercy in providing new life",
    "49.2.8": "Salvation by grace through faith",
    "49.2.11": "Gentiles' past alienation",
    "49.2.13": "Reconciliation through Christ's blood",
    "49.2.19": "Gentiles as fellow citizens in God's household",
    "49.3.1": "The mystery revealed to Paul",
    "49.3.7": "Paul's role as a minister to the Gentiles",
    "49.3.14": "Paul's prayer for spiritual growth and unity",
    "49.4.1": "Exhortation to unity",
    "49.4.7": "Christ's gift to the Church",
    "49.4.11": "The role of different gifts and leaders",
    "49.4.14": "Attaining mature unity",
    "49.4.17": "Rejecting the old self",
    "49.4.25": "Examples of transformed behavior",
    "49.5.1": "Walking in love",
    "49.5.8": "Walking as children of light",
    "49.5.15": "Walking in wisdom",
    "49.5.22": "Wives and husbands",
    "49.6.1": "Children and parents",
    "49.6.5": "Slaves and masters",
    "49.6.10": "Putting on the full armor of God",
    "49.6.18": "Praying in the Spirit",
    "49.6.21": "Tychicus, Paul's messenger",
    "49.6.23": "Benediction",
    "50.1.1": "Greetings",
    "50.1.2": "Grace and Peace",
    "50.1.3": "Thanksgiving for Partnership in the Gospel",
    "50.1.7": "Paul's Affection for the Philippians",
    "50.1.9": "Prayer for Spiritual Growth",
    "50.1.12": "God's Sovereignty in Paul's Imprisonment",
    "50.1.15": "Preaching Christ for Different Motivations",
    "50.1.19": "Confidence in Christ's Deliverance",
    "50.1.22": "Struggle Between Life and Death",
    "50.1.27": "Exhortation to Conduct Worthy of the Gospel",
    "50.2.1": "Call for Unity and Humility",
    "50.2.5": "Christ's Humility and Exaltation",
    "50.2.12": "Working Out One's Salvation",
    "50.2.14": "A Blameless and Innocent Generation",
    "50.2.17": "Paul's Joy and Sacrificial Service",
    "50.2.19": "Timothy's Genuine Concern",
    "50.2.25": "Epaphroditus's Illness and Ministry",
    "50.3.1": "Warning Against False Teachers",
    "50.3.3": "Righteousness from God",
    "50.3.10": "Knowing Christ and the Resurrection",
    "50.3.12": "Not Yet Perfect but Pressing On",
    "50.3.15": "Maturity and the Mind of Christ",
    "50.3.17": "Warning Against Enemies of the Cross",
    "50.3.20": "Our Citizenship in Heaven",
    "50.4.1": "Exhortation to Stand Fast",
    "50.4.2": "Urging Harmony for Euodia and Syntyche",
    "50.4.4": "The Peace of God in All Situations",
    "50.4.8": "Meditate on What Is Good",
    "50.4.10": "Content in All Circumstances",
    "50.4.15": "The Philippians' Gift to Paul",
    "50.4.21": "Final Greetings and Benediction",
    "51.1.1": "Greeting",
    "51.1.3": "Paul's Gratitude for the Colossians' Faith",
    "51.1.9": "Paul's Prayer for Spiritual Growth",
    "51.1.15": "Christ as the Image of God and Firstborn",
    "51.1.18": "Christ as the Head of the Church",
    "51.1.21": "Reconciliation through Christ",
    "51.1.24": "Paul's Suffering and Stewardship",
    "51.2.1": "Paul's Concern and Struggle for the Church",
    "51.2.6": "Walk in Christ, Your Foundation",
    "51.2.8": "Warning Against False Philosophy",
    "51.2.11": "Freedom through Christ's Work",
    "51.2.16": "Warning Against Legalism and Asceticism",
    "51.3.1": "Seek the Things Above",
    "51.3.5": "Put to Death Your Earthly Nature",
    "51.3.12": "Put on the New Self",
    "51.3.18": "Wives and Husbands",
    "51.3.20": "Children and Parents",
    "51.3.22": "Slaves and Masters",
    "51.4.2": "Devotion to Prayer and Thanksgiving",
    "51.4.5": "Walk in Wisdom with Outsiders",
    "51.4.7": "Tychicus and Onesimus",
    "51.4.10": "Greetings from Paul's Companions",
    "51.4.15": "Instructions for the Colossians",
    "51.4.18": "Paul's Closing Message",
    "52.1.1": "Salutation",
    "52.1.2": "Remembrance of their faith, love, and hope",
    "52.1.4": "Election and reception of the gospel",
    "52.1.7": "Examples to other believers",
    "52.1.9": "Turning from idols to serve God",
    "52.2.1": "Genuine motives",
    "52.2.5": "Tender care",
    "52.2.9": "Labor and hardship",
    "52.2.11": "Encouragement and motivation",
    "52.2.13": "Chosen for salvation",
    "52.2.15": "Exhortation to stand firm",
    "52.2.16": "Prayer for comfort and strength",
    "52.3.1": "Reason for sending Timothy",
    "52.3.4": "Faith in the Thessalonians' faith",
    "52.3.6": "Their faith and love",
    "52.3.9": "Paul's gratitude",
    "52.3.11": "Prayer for direction and love",
    "52.3.13": "Prayer for blamelessness",
    "52.4.1": "Plea for sanctification",
    "52.4.4": "Instructions for purity",
    "52.4.8": "Warning against disregard",
    "52.4.9": "Encouragement in love",
    "52.4.11": "Exhortation to work and live quietly",
    "52.4.13": "Comfort for the grieving",
    "52.4.15": "The Lord's return",
    "52.4.18": "Encouragement to each other",
    "52.5.1": "The unpredictable nature of the Day of the Lord",
    "52.5.3": "The sudden destruction",
    "52.5.5": "Contrast between the righteous and wicked",
    "52.5.9": "Salvation and encouragement",
    "52.5.12": "Respect and Admonition for Church Leaders",
    "52.5.14": "Instructions for various situations",
    "52.5.16": "Pursuit of spiritual practices",
    "52.5.19": "Guidelines for prophetic messages",
    "52.5.23": "Sanctification and preservation",
    "52.5.25": "Final requests and greetings",
    "53.1.1": "Greeting",
    "53.1.3": "Thanksgiving for Faith and Love",
    "53.1.5": "God's Righteous Judgment",
    "53.1.11": "Paul's Prayer for Spiritual Growth",
    "53.2.1": "False Teaching About Christ's Return",
    "53.2.3": "The Man of Lawlessness",
    "53.2.11": "God's Judicial Delusion",
    "53.2.13": "Thanksgiving for the Church's Election",
    "53.2.15": "Exhortation to Persevere",
    "53.3.1": "Prayer Request for Gospel Ministry",
    "53.3.3": "Confidence in the Lord's Protection",
    "53.3.6": "Instructions on Church Discipline",
    "53.3.16": "Final Greeting and Benediction",
    "54.1.1": "Greeting",
    "54.1.2": "Recipient",
    "54.1.3": "Warning against False Teachers",
    "54.1.5": "Purpose of the Law",
    "54.1.12": "His Conversion",
    "54.1.15": "Proclamation of Christ's Purpose",
    "54.1.17": "Praise to God",
    "54.1.18": "Charge to Timothy",
    "54.1.19": "The Faith of Hymenaeus and Alexander",
    "54.3.1": "Desire for Leadership",
    "54.3.2": "Character and Conduct",
    "54.3.8": "Character and Conduct",
    "54.3.13": "Reward for Service",
    "54.4.1": "Warnings about Apostasy",
    "54.4.6": "Instructions for a Godly Minister",
    "54.4.11": "Timothy's Personal Conduct",
    "54.5.1": "Treatment of the Members",
    "54.5.3": "Treatment of True Widows",
    "54.5.7": "Family Responsibilities",
    "54.5.9": "Conditions for Widows",
    "54.5.11": "Warning about Younger Widows",
    "54.5.16": "Family Responsibility for Widows",
    "54.5.17": "Honor and Wages",
    "54.5.19": "Accusations and Discipline",
    "54.5.21": "Impartiality in Judgment",
    "54.5.23": "Timothy's Health",
    "54.5.24": "Discerning the Character of Others",
    "54.6.1": "Instructions to Slaves",
    "54.6.3": "False Teachers and Greed",
    "54.6.6": "True Contentment and Godliness",
    "54.6.9": "The Dangers of Wealth",
    "54.6.11": "Pursuit of Godliness",
    "54.6.17": "Instructions to the Rich",
    "54.6.20": "Safeguarding the Deposit of Faith",
    "55.1.1": "Salutation",
    "55.1.3": "Paul's Thanksgiving and Encouragement",
    "55.1.8": "Suffering for the Gospel",
    "55.1.15": "Faithfulness and Unfaithfulness",
    "55.2.1": "Strengthening in Ministry",
    "55.2.14": "Rightly Handling the Word",
    "55.3.1": "Godlessness in the Last Days",
    "55.3.10": "Paul's Charge to Timothy",
    "55.4.1": "Final Instructions and the Crown of Righteousness",
    "55.4.9": "Personal Concerns and Final Greetings",
    "56.1.1": "Greeting",
    "56.1.4": "Recipient",
    "56.1.5": "The Purpose of Titus' Ministry",
    "56.1.6": "The Requirements",
    "56.1.8": "The Character of a Leader",
    "56.1.10": "Descriptions of False Teachers",
    "56.1.13": "Corrective Measures for False Teachers",
    "56.1.15": "Consequences of False Teaching",
    "56.2.1": "Instructions for Different Groups",
    "56.2.7": "The Role of Titus",
    "56.2.9": "Instructions for Slaves",
    "56.2.11": "Saving Grace",
    "56.2.12": "Instructing Grace",
    "56.2.14": "Redeeming Grace",
    "56.2.15": "Authoritative Teaching",
    "56.3.1": "Submission to Authorities",
    "56.3.3": "A Reminder of their Past and God's Mercy",
    "56.3.8": "Encouragement in Good Works",
    "56.3.9": "Dealing with Divisive People",
    "56.3.12": "Guidance for Titus and Other Leaders",
    "56.3.14": "Exhortation to Good works and Greetings",
    "57.1.1": "Salutation",
    "57.1.4": "Paul's Thanksgiving for Philemon",
    "57.1.6": "Paul's Prayer for Philemon",
    "57.1.7": "Philemon's Encouragement to Others",
    "57.1.8": "An Appeal Instead of a Command",
    "57.1.10": "Introducing Onesimus",
    "57.1.12": "Paul's Desire to be with Onesimus",
    "57.1.15": "Purpose of Onesimus's Departure",
    "57.1.17": "Philemon's Relationship with Paul",
    "57.1.20": "Paul's Expectation of Philemon's Obedience",
    "57.1.22": "Paul's Hope to Visit",
    "57.1.23": "Greetings from Fellow Workers",
    "57.1.25": "Conclusion with a Wish for Grace",
    "58.1.1": "God's revelation through Christ",
    "58.1.2": "The exalted nature of Christ",
    "58.1.5": "Superiority demonstrated through scriptures",
    "58.2.1": "Warning against neglecting salvation",
    "58.2.5": "Christ's humiliation and exaltation",
    "58.2.10": "Christ's role as trailblazer and sanctifier",
    "58.2.14": "Christ's victory over death and the devil",
    "58.2.17": "Christ as the faithful High Priest",
    "58.3.1": "Comparing Christ and Moses",
    "58.3.7": "Warning against unbelief and disobedience",
    "58.4.1": "The promise of God's rest",
    "58.4.12": "The power of God's word",
    "58.4.14": "Christ's compassionate priesthood",
    "58.5.11": "The need for spiritual growth",
    "58.6.1": "The foundation for spiritual maturity",
    "58.6.9": "The assurance of God's promises",
    "58.7.1": "Melchizedek and Christ's eternal priesthood",
    "58.8.1": "Christ's exalted ministry",
    "58.8.7": "The promised new covenant",
    "58.9.1": "The superiority of Christ's sacrifice",
    "58.9.15": "The necessity and effectiveness of Christ's sacrifice",
    "58.10.1": "Christ's single perfect offering",
    "58.10.19": "Encouragement to persevere",
    "58.11.1": "The examples of faith throughout history",
    "58.12.1": "Jesus as the founder and perfecter of faith",
    "58.12.4": "Enduring discipline as children of God",
    "58.12.14": "The call for holiness and gratitude",
    "58.13.1": "Exhortations to love, purity, and contentment",
    "58.13.7": "Exhortations to honor leaders and hold to sound doctrine",
    "58.13.18": "Request for prayer and final greetings",
    "59.1.1": "Greetings by James",
    "59.1.2": "Joy in Trials",
    "59.1.5": "Seeking Wisdom",
    "59.1.9": "Humility in Riches and Poverty",
    "59.1.12": "Perseverance in Temptations",
    "59.1.16": "The Source of Good Gifts",
    "59.1.19": "Swift to Hear, Slow to Speak",
    "59.1.21": "Putting Away Filthiness",
    "59.1.22": "Hearing and Doing the Word",
    "59.1.26": "True Religion",
    "59.2.1": "Favoritism and Discrimination",
    "59.2.5": "The Rich vs. the Poor",
    "59.2.8": "Loving Others Equally",
    "59.2.12": "Judgement and the Law of Liberty",
    "59.2.14": "Faith Without Works is Dead",
    "59.2.18": "Examples of Living Faith",
    "59.2.23": "The Faith of Rahab",
    "59.2.26": "Faith Perfected by Works",
    "59.3.1": "Teaching and Accountability",
    "59.3.3": "The Power of the Tongue",
    "59.3.7": "Taming the Tongue",
    "59.3.13": "True Wisdom",
    "59.4.1": "Causes of Quarrels and Conflicts",
    "59.4.4": "Adultery, Enmity, and Friendship with the World",
    "59.4.6": "God's Grace and Humility",
    "59.4.7": "Drawing Near to God",
    "59.4.11": "Judging Others and the Law",
    "59.4.13": "The Uncertainty of Life",
    "59.4.16": "Boasting and Pride",
    "59.4.17": "Doing Good",
    "59.5.1": "The Miseries of the Rich",
    "59.5.4": "Exploitation and Injustice",
    "59.5.7": "Patience in Suffering",
    "59.5.9": "Not Grumbling and Judgment",
    "59.5.10": "Examples of Endurance",
    "59.5.12": "Honesty in Speech",
    "59.5.13": "Prayer, Praise, and Healing",
    "59.5.16": "Confession and Intercession",
    "59.5.19": "Restoring the Wandering Believer",
    "60.1.1": "Introduction",
    "60.1.3": "Praise for Salvation",
    "60.1.6": "Rejoicing in Trials",
    "60.1.10": "Prophets and the Gospel",
    "60.1.13": "Call to Holiness",
    "60.1.17": "Living in Reverent Fear",
    "60.1.22": "Love One Another Sincerely",
    "60.2.1": "Craving Spiritual Nourishment",
    "60.2.4": "Living Stones and a Spiritual House",
    "60.2.9": "The Privileges of God's People",
    "60.2.11": "Conduct among the Gentiles",
    "60.2.13": "Submission to Authorities",
    "60.2.18": "Slaves and Masters",
    "60.2.21": "Christ: The Ultimate Example",
    "60.3.1": "Wives and Husbands",
    "60.3.8": "Living in Harmony",
    "60.3.13": "Suffering for Doing Good",
    "60.3.18": "Christ's Suffering and Victory",
    "60.4.1": "The New Life in Christ",
    "60.4.7": "The End is Near",
    "60.4.12": "Rejoicing in Sufferings",
    "60.5.1": "Responsibilities of Elders and Younger Members",
    "60.5.6": "Humility and Anxiety",
    "60.5.8": "Resisting the Devil",
    "60.5.10": "God's Grace and Restoration",
    "60.5.12": "Final Words and Purpose",
    "60.5.13": "Greetings from the Community",
    "60.5.14": "Benediction",
    "61.1.1": "Greetings and Introduction",
    "61.1.3": "God's Power and Promises",
    "61.1.5": "The Process of Spiritual Growth",
    "61.1.8": "Assurance and Diligence in Faith",
    "61.1.12": "Reminder of Christian Teachings",
    "61.1.16": "The Validity of Peter's Witness",
    "61.1.19": "The Inspiration of Scripture",
    "61.2.1": "Introduction of False Teachers",
    "61.2.4": "God's Judgment on the Ungodly",
    "61.2.10": "The Behavior of False Teachers",
    "61.2.17": "The Fate and Influence of False Teachers",
    "61.2.20": "Warnings for Those Who Follow False Teachers",
    "61.3.1": "Reminder and Mockers in the Last Days",
    "61.3.5": "God's Timing and the Day of the Lord",
    "61.3.10": "The Coming Judgment",
    "61.3.14": "Call to Holy Living",
    "61.3.15": "Exhortation to Understand Scripture",
    "61.3.17": "Encouragement to Grow in Grace and Knowledge",
    "61.3.18": "Doxology: The Glory of God",
    "62.1.1": "The witnesses of Jesus",
    "62.1.3": "Proclaimed for fellowship",
    "62.1.5": "The message of light",
    "62.1.8": "Confession and forgiveness",
    "62.2.1": "The advocate, Jesus Christ",
    "62.2.3": "Knowing God through obedience",
    "62.2.6": "Walking as Jesus did",
    "62.2.7": "The old and new commandment",
    "62.2.9": "Living in the light",
    "62.2.12": "To the children, fathers, and young men",
    "62.2.15": "Not loving the world",
    "62.2.17": "The world passes away",
    "62.2.18": "Be aware of the antichrists",
    "62.2.24": "The promise of eternal life",
    "62.2.26": "The anointing and discernment",
    "62.2.28": "Abide in Christ",
    "62.3.1": "The children of God",
    "62.3.4": "Practicing righteousness",
    "62.3.8": "The contrast between God's children and the devil's children",
    "62.3.11": "The message of love",
    "62.3.16": "Love put into action",
    "62.3.19": "Assurance through obedience",
    "62.3.23": "Commandment and abiding",
    "62.4.1": "Testing spirits",
    "62.4.4": "Overcoming the world",
    "62.4.7": "Love, the divine origin",
    "62.4.9": "God's love demonstrated",
    "62.4.11": "Loving one another",
    "62.4.13": "God's love, our assurance",
    "62.4.17": "Confidence in the day of judgment",
    "62.4.19": "If we love God, we love others",
    "62.5.1": "Born of God",
    "62.5.2": "Loving and believing",
    "62.5.6": "The witness of the Spirit, water, and blood",
    "62.5.9": "The testimony of eternal life",
    "62.5.13": "The certainty of eternal life",
    "62.5.14": "Confidence in prayer",
    "62.5.16": "Interceding for others",
    "62.5.18": "Assurance of God's protection",
    "62.5.21": "Guard against idols",
    "63.1.1": "Introduction",
    "63.1.4": "Encouragement in walking in truth and love",
    "63.1.7": "Warning against false teachers",
    "63.1.12": "Conclusion",
    "64.1.1": "Introduction and Greeting",
    "64.1.3": "Gaius Praised for His Hospitality and Faithfulness",
    "64.1.9": "Condemnation of Diotrephes for His Hostility and Selfishness",
    "64.1.12": "Commendation of Demetrius for His Good Testimony",
    "64.1.13": "Conclusion and Final Greetings",
    "65.1.1": "Greeting",
    "65.1.3": "Call to Contend for the Faith",
    "65.1.5": "Reminders of God's Judgment",
    "65.1.8": "Indictment of the False Teachers",
    "65.1.14": "Enoch's Prophecy",
    "65.1.16": "Description of the False Teachers",
    "65.1.20": "Exhortation to Build Up and Persevere",
    "65.1.24": "Doxology: Praise to God",
    "66.1.1": "Prologue",
    "66.1.3": "Benediction",
    "66.1.4": "Greetings and Doxology",
    "66.1.9": "John's Commission",
    "66.1.12": "Vision of the Glorified Christ",
    "66.1.17": "Jesus' Message to John",
    "66.2.1": "Message to Ephesus",
    "66.2.8": "Message to Smyrna",
    "66.2.12": "Message to Pergamos",
    "66.2.18": "Message to Thyatira",
    "66.3.1": "Message to Sardis",
    "66.3.7": "Message to Philadelphia",
    "66.3.14": "Message to Laodicea",
    "66.4.1": "Vision of the Throne in Heaven",
    "66.5.1": "The Lamb and the Scroll",
    "66.6.1": "First Seal: The Conqueror",
    "66.6.3": "Second Seal: Conflict and Warfare",
    "66.6.5": "Third Seal: Famine and Scarcity",
    "66.6.7": "Fourth Seal: Death and Hades",
    "66.6.9": "Fifth Seal: Martyrs' Cry",
    "66.6.12": "Sixth Seal: Cosmic Disturbances",
    "66.7.1": "The Sealing of the 144,000",
    "66.7.9": "The Great Multitude in Heaven",
    "66.8.1": "Introduction to the Trumpets",
    "66.8.7": "First Trumpet: Hail, Fire, and Blood",
    "66.8.8": "Second Trumpet: The Burning Mountain",
    "66.8.10": "Third Trumpet: The Falling Star",
    "66.8.12": "Fourth Trumpet: Darkness",
    "66.9.1": "Fifth Trumpet: Locusts from the Abyss",
    "66.9.13": "Sixth Trumpet: Army from the Euphrates",
    "66.10.1": "The Angel and the Little Scroll",
    "66.11.1": "The Two Witnesses",
    "66.11.15": "Seventh Trumpet: The Third Woe",
    "66.12.1": "The Woman, the Child, and the Dragon",
    "66.13.1": "The Beast from the Sea",
    "66.13.11": "The Beast from the Earth",
    "66.14.1": "The Lamb and the 144,000",
    "66.14.6": "The Angelic Proclamations",
    "66.14.14": "The Harvest and the Vintage",
    "66.15.1": "Prelude to the Bowl Judgments",
    "66.16.1": "First Bowl: Loathsome Sores",
    "66.16.3": "Second Bowl: Seas Turn to Blood",
    "66.16.4": "Third Bowl: Rivers and Springs Become Blood",
    "66.16.8": "Fourth Bowl: Intense Heat",
    "66.16.10": "Fifth Bowl: Darkness",
    "66.16.12": "Sixth Bowl: The Euphrates Dried Up",
    "66.16.17": "Seventh Bowl: The Great Earthquake and Hailstorm",
    "66.17.1": "The Vision of the Scarlet Woman and the Scarlet Beast",
    "66.18.1": "The Lament for Babylon",
    "66.19.1": "Praise for Babylon's Fall",
    "66.19.6": "The Marriage Supper of the Lamb",
    "66.19.11": "The Rider on the White Horse",
    "66.19.17": "Defeat of the Beast and the False Prophet",
    "66.20.1": "Satan Bound for 1,000 Years",
    "66.20.4": "The First Resurrection and Reign of the Saints",
    "66.20.7": "Satan's Last Rebellion and Doom",
    "66.20.11": "The Great White Throne Judgment",
    "66.21.1": "The New Jerusalem",
    "66.21.9": "Description of the New Jerusalem",
    "66.22.1": "The River of Life and Tree of Life",
    "66.22.6": "Final Messages and Closing",
}
